@@ -2,7 +2,6 @@
 /* vim: set expandtab sw=4 ts=4 sts=4: */
 /**
  *
- * @version $Id: db_structure.php 13034 2009-10-12 21:47:40Z lem9 $
  * @package phpMyAdmin
  */
 
@@ -10,9 +9,9 @@
  *
  */
 require_once './libraries/common.inc.php';
-require_once './libraries/Table.class.php';
 
-$GLOBALS['js_include'][] = 'mootools.js';
+$GLOBALS['js_include'][] = 'jquery/jquery-ui-1.8.custom.js';
+$GLOBALS['js_include'][] = 'db_structure.js';
 
 /**
  * Prepares the tables list if the user where not redirected to this script
@@ -24,7 +23,14 @@ if (empty($is_info)) {
       || isset($mult_btn)) {
         $action = 'db_structure.php';
         $err_url = 'db_structure.php?'. PMA_generate_common_url($db);
-        require './libraries/mult_submits.inc.php';
+
+        // see bug #2794840; in this case, code path is:
+        // db_structure.php -> libraries/mult_submits.inc.php -> sql.php
+        // -> db_structure.php and if we got an error on the multi submit,
+        // we must display it here and not call again mult_submits.inc.php
+        if (! isset($error) || FALSE === $error) {
+            require './libraries/mult_submits.inc.php';
+        }
         if (empty($message)) {
             $message = PMA_Message::success();
         }
@@ -35,191 +41,49 @@ if (empty($is_info)) {
     // Gets the database structure
     $sub_part = '_structure';
     require './libraries/db_info.inc.php';
+
+    require_once './libraries/replication.inc.php';
 }
 
-// 1. No tables
-if ($num_tables == 0) {
-    echo '<p>' . $strNoTablesFound . '</p>' . "\n";
-
-    if (empty($db_is_information_schema)) {
-        require './libraries/display_create_table.lib.php';
-    } // end if (Create Table dialog)
-
-    /**
-     * Displays the footer
-     */
-    require_once './libraries/footer.inc.php';
-    exit;
-}
-
-// else
-// 2. Shows table informations - staybyte - 11 June 2001
-
 require_once './libraries/bookmark.lib.php';
 
 require_once './libraries/mysql_charsets.lib.php';
 $db_collation = PMA_getDbCollation($db);
 
-// Display function
-/**
- * void PMA_TableHeader([bool $db_is_information_schema = false])
- * display table header (<table><thead>...</thead><tbody>)
- *
- * @uses    PMA_showHint()
- * @uses    $GLOBALS['cfg']['PropertiesNumColumns']
- * @uses    $GLOBALS['is_show_stats']
- * @uses    $GLOBALS['strTable']
- * @uses    $GLOBALS['strAction']
- * @uses    $GLOBALS['strRecords']
- * @uses    $GLOBALS['strApproximateCount']
- * @uses    $GLOBALS['strType']
- * @uses    $GLOBALS['strCollation']
- * @uses    $GLOBALS['strSize']
- * @uses    $GLOBALS['strOverhead']
- * @uses    $GLOBALS['structure_tbl_col_cnt']
- * @uses    PMA_SortableTableHeader()
- * @param   boolean $db_is_information_schema
- */
-function PMA_TableHeader($db_is_information_schema = false)
-{
-    $cnt = 0; // Let's count the columns...
+// in a separate file to avoid redeclaration of functions in some code paths
+require_once './libraries/db_structure.lib.php';
+$titles = PMA_buildActionTitles();
 
-    if ($db_is_information_schema) {
-        $action_colspan = 3;
-    } else {
-        $action_colspan = 6;
-    }
+// 1. No tables
+if ($num_tables == 0) {
+	echo '<p>' . __('No tables found in database') . '</p>' . "\n";
 
-    echo '<table class="data" style="float: left;">' . "\n"
-        .'<thead>' . "\n"
-        .'<tr><th></th>' . "\n"
-        .'    <th>' . PMA_SortableTableHeader($GLOBALS['strTable'], 'table') . '</th>' . "\n"
-        .'    <th colspan="' . $action_colspan . '">' . "\n"
-        .'        ' . $GLOBALS['strAction'] . "\n"
-        .'    </th>'
-        .'    <th>' . PMA_SortableTableHeader($GLOBALS['strRecords'], 'records')
-        .PMA_showHint(PMA_sanitize($GLOBALS['strApproximateCount'])) . "\n"
-        .'    </th>' . "\n";
-    if (!($GLOBALS['cfg']['PropertiesNumColumns'] > 1)) {
-        echo '    <th>' . PMA_SortableTableHeader($GLOBALS['strType'], 'type') . '</th>' . "\n";
-        $cnt++;
-        echo '    <th>' . PMA_SortableTableHeader($GLOBALS['strCollation'], 'collation') . '</th>' . "\n";
-        $cnt++;
-    }
-    if ($GLOBALS['is_show_stats']) {
-        echo '    <th>' . PMA_SortableTableHeader($GLOBALS['strSize'], 'size') . '</th>' . "\n"
-           . '    <th>' . PMA_SortableTableHeader($GLOBALS['strOverhead'], 'overhead') . '</th>' . "\n";
-        $cnt += 2;
-    }
-    echo '</tr>' . "\n";
-    echo '</thead>' . "\n";
-    echo '<tbody>' . "\n";
-    $GLOBALS['structure_tbl_col_cnt'] = $cnt + $action_colspan + 3;
-} // end function PMA_TableHeader()
+	// Routines
+	require './libraries/db_routines.inc.php';
 
-/**
- * Creates a clickable column header for table information
- *
- * @param   string  title to use for the link
- * @param   string  corresponds to sortable data name mapped in libraries/db_info.inc.php  
- * @returns string  link to be displayed in the table header
- */
-function PMA_SortableTableHeader($title, $sort)
-{
-    // Set some defaults
-    $requested_sort = 'table';
-    $requested_sort_order = 'ASC';
-    $future_sort_order = 'ASC';
-    
-    // If the user requested a sort
-    if (isset($_REQUEST['sort'])) {
-        $requested_sort = $_REQUEST['sort'];
+	// Events
+	if (PMA_MYSQL_INT_VERSION > 50100) {
+	    require './libraries/db_events.inc.php';
+	}
 
-        if (isset($_REQUEST['sort_order'])) {
-            $requested_sort_order = $_REQUEST['sort_order'];
-        }
-    }
+	if (empty($db_is_information_schema)) {
+		require './libraries/display_create_table.lib.php';
+	} // end if (Create Table dialog)
 
-    $order_img = '';
-    $order_link_params = array();
-    $order_link_params['title'] = $GLOBALS['strSort'];
-
-    // If this column was requested to be sorted.
-    if ($requested_sort == $sort) {
-        if ($requested_sort_order == 'ASC') {
-            $future_sort_order = 'DESC';
-            // current sort order is ASC
-            $order_img  = ' <img class="icon" src="' . $GLOBALS['pmaThemeImage'] . 's_asc.png" width="11" height="9" alt="'. $GLOBALS['strAscending'] . '" title="'. $GLOBALS['strAscending'] . '" id="sort_arrow" />';
-            // but on mouse over, show the reverse order (DESC)
-            $order_link_params['onmouseover'] = 'if(document.getElementById(\'sort_arrow\')){ document.getElementById(\'sort_arrow\').src=\'' . $GLOBALS['pmaThemeImage'] . 's_desc.png\'; }';
-            // on mouse out, show current sort order (ASC)
-            $order_link_params['onmouseout']  = 'if(document.getElementById(\'sort_arrow\')){ document.getElementById(\'sort_arrow\').src=\'' . $GLOBALS['pmaThemeImage'] . 's_asc.png\'; }';
-        } else {
-            // current sort order is DESC
-            $order_img  = ' <img class="icon" src="' . $GLOBALS['pmaThemeImage'] . 's_desc.png" width="11" height="9" alt="'. $GLOBALS['strDescending'] . '" title="'. $GLOBALS['strDescending'] . '" id="sort_arrow" />';
-            // but on mouse over, show the reverse order (ASC)
-            $order_link_params['onmouseover'] = 'if(document.getElementById(\'sort_arrow\')){ document.getElementById(\'sort_arrow\').src=\'' . $GLOBALS['pmaThemeImage'] . 's_asc.png\'; }';
-            // on mouse out, show current sort order (DESC)
-            $order_link_params['onmouseout']  = 'if(document.getElementById(\'sort_arrow\')){ document.getElementById(\'sort_arrow\').src=\'' . $GLOBALS['pmaThemeImage'] . 's_desc.png\'; }';
-        }
-    }
-
-    $_url_params = array(
-        'db' => $_REQUEST['db'],
-    );
-
-    $url = 'db_structure.php'.PMA_generate_common_url($_url_params);
-    // We set the position back to 0 every time they sort.
-    $url .= "&amp;pos=0&amp;sort=$sort&amp;sort_order=$future_sort_order";
-
-    return PMA_linkOrButton($url, $title . $order_img, $order_link_params);
-} // end function PMA_SortableTableHeader()
-
-
-$titles = array();
-if (true == $cfg['PropertiesIconic']) {
-    $titles['Browse']     = '<img class="icon" width="16" height="16" src="' .$pmaThemeImage . 'b_browse.png" alt="' . $strBrowse . '" title="' . $strBrowse . '" />';
-    $titles['NoBrowse']   = '<img class="icon" width="16" height="16" src="' .$pmaThemeImage . 'bd_browse.png" alt="' . $strBrowse . '" title="' . $strBrowse . '" />';
-    $titles['Search']     = '<img class="icon" width="16" height="16" src="' .$pmaThemeImage . 'b_select.png" alt="' . $strSearch . '" title="' . $strSearch . '" />';
-    $titles['NoSearch']   = '<img class="icon" width="16" height="16" src="' .$pmaThemeImage . 'bd_select.png" alt="' . $strSearch . '" title="' . $strSearch . '" />';
-    $titles['Insert']     = '<img class="icon" width="16" height="16" src="' .$pmaThemeImage . 'b_insrow.png" alt="' . $strInsert . '" title="' . $strInsert . '" />';
-    $titles['NoInsert']   = '<img class="icon" width="16" height="16" src="' .$pmaThemeImage . 'bd_insrow.png" alt="' . $strInsert . '" title="' . $strInsert . '" />';
-    $titles['Structure']  = '<img class="icon" width="16" height="16" src="' .$pmaThemeImage . 'b_props.png" alt="' . $strStructure . '" title="' . $strStructure . '" />';
-    $titles['Drop']       = '<img class="icon" width="16" height="16" src="' .$pmaThemeImage . 'b_drop.png" alt="' . $strDrop . '" title="' . $strDrop . '" />';
-    $titles['NoDrop']     = '<img class="icon" width="16" height="16" src="' .$pmaThemeImage . 'bd_drop.png" alt="' . $strDrop . '" title="' . $strDrop . '" />';
-    $titles['Empty']      = '<img class="icon" width="16" height="16" src="' .$pmaThemeImage . 'b_empty.png" alt="' . $strEmpty . '" title="' . $strEmpty . '" />';
-    $titles['NoEmpty']    = '<img class="icon" width="16" height="16" src="' .$pmaThemeImage . 'bd_empty.png" alt="' . $strEmpty . '" title="' . $strEmpty . '" />';
-
-    if ('both' === $cfg['PropertiesIconic']) {
-        $titles['Browse']     .= $strBrowse;
-        $titles['Search']     .= $strSearch;
-        $titles['NoBrowse']   .= $strBrowse;
-        $titles['NoSearch']   .= $strSearch;
-        $titles['Insert']     .= $strInsert;
-        $titles['NoInsert']   .= $strInsert;
-        $titles['Structure']  .= $strStructure;
-        $titles['Drop']       .= $strDrop;
-        $titles['NoDrop']     .= $strDrop;
-        $titles['Empty']      .= $strEmpty;
-        $titles['NoEmpty']    .= $strEmpty;
-    }
-} else {
-    $titles['Browse']     = $strBrowse;
-    $titles['Search']     = $strSearch;
-    $titles['NoBrowse']   = $strBrowse;
-    $titles['NoSearch']   = $strSearch;
-    $titles['Insert']     = $strInsert;
-    $titles['NoInsert']   = $strInsert;
-    $titles['Structure']  = $strStructure;
-    $titles['Drop']       = $strDrop;
-    $titles['NoDrop']     = $strDrop;
-    $titles['Empty']      = $strEmpty;
-    $titles['NoEmpty']    = $strEmpty;
+	/**
+	 * Displays the footer
+	 */
+	require_once './libraries/footer.inc.php';
+	exit;
 }
 
+// else
+// 2. Shows table informations
+
 /**
  * Displays the tables list
  */
+echo '<div id="tableslistcontainer">';
 $_url_params = array(
     'pos' => $pos,
     'db'  => $db);
@@ -240,7 +104,7 @@ PMA_listNavigator($total_num_tables, $pos, $_url_params, 'db_structure.php', 'fr
 <?php
 echo PMA_generate_common_hidden_inputs($db);
 
-PMA_TableHeader($db_is_information_schema);
+PMA_TableHeader($db_is_information_schema, $server_slave_status);
 
 $i = $sum_entries = 0;
 $sum_size       = (double) 0;
@@ -255,29 +119,15 @@ $hidden_fields = array();
 $odd_row       = true;
 $sum_row_count_pre = '';
 
-// added by rajk - for blobstreaming
-$PMA_Config = $_SESSION['PMA_Config'];
-
-if (!empty($PMA_Config))
-    $session_bs_tables = $PMA_Config->get('BLOBSTREAMING_TABLES'); // list of blobstreaming tables
-
 $tableReductionCount = 0;   // the amount to reduce the table count by
 
 foreach ($tables as $keyname => $each_table) {
-    if (isset($session_bs_tables))
-    {
-        // compare table name against blobstreaming tables
-        foreach ($session_bs_tables as $table_key=>$table_val)
-            // if the table is a blobstreaming table, reduce table count and skip outer foreach loop
-            if ($table_key == $keyname)
-            {
-                $tableReductionCount++;
-                continue 2;
-            }
+    if (PMA_BS_IsHiddenTable($keyname)) {
+        $tableReductionCount++;
+        continue;
     }
 
-    // loic1: Patch from Joshua Nye <josh at boxcarmedia.com> to get valid
-    //        statistics whatever is the table type
+    // Get valid statistics whatever is the table type
 
     $table_is_view = false;
     $table_encoded = urlencode($each_table['TABLE_NAME']);
@@ -289,16 +139,19 @@ foreach ($tables as $keyname => $each_table) {
 
     switch ( $each_table['ENGINE']) {
         // MyISAM, ISAM or Heap table: Row count, data size and index size
-        // are accurate.
+        // are accurate; data size is accurate for ARCHIVE
         case 'MyISAM' :
         case 'ISAM' :
         case 'HEAP' :
         case 'MEMORY' :
+        case 'ARCHIVE' :
+        case 'Aria' :
+        case 'Maria' :
             if ($db_is_information_schema) {
                 $each_table['Rows'] = PMA_Table::countRecords($db,
-                    $each_table['Name'], $return = true);
+                    $each_table['Name']);
             }
-                
+
             if ($is_show_stats) {
                 $tblsize                    =  doubleval($each_table['Data_length']) + doubleval($each_table['Index_length']);
                 $sum_size                   += $tblsize;
@@ -316,7 +169,7 @@ foreach ($tables as $keyname => $each_table) {
             if ($each_table['TABLE_ROWS'] < $GLOBALS['cfg']['MaxExactCount']) {
                 $each_table['COUNTED'] = true;
                 $each_table['TABLE_ROWS'] = PMA_Table::countRecords($db,
-                    $each_table['TABLE_NAME'], $return = true, $force_exact = true,
+                    $each_table['TABLE_NAME'], $force_exact = true,
                     $is_view = false);
             } else {
                 $each_table['COUNTED'] = false;
@@ -329,7 +182,11 @@ foreach ($tables as $keyname => $each_table) {
             }
             //$display_rows                   =  ' - ';
             break;
+	    // Mysql 5.0.x (and lower) uses MRG_MyISAM and MySQL 5.1.x (and higher) uses MRG_MYISAM
+        // Both are aliases for MERGE
         case 'MRG_MyISAM' :
+        case 'MRG_MYISAM' :
+        case 'MERGE' :
         case 'BerkeleyDB' :
             // Merge or BerkleyDB table: Only row count is accurate.
             if ($is_show_stats) {
@@ -338,14 +195,14 @@ foreach ($tables as $keyname => $each_table) {
             }
             break;
             // for a view, the ENGINE is sometimes reported as null,
-            // or on some servers it's reported as "SYSTEM VIEW" 
+            // or on some servers it's reported as "SYSTEM VIEW"
         case null :
         case 'SYSTEM VIEW' :
-            // if table is broken, Engine is reported as null, so one more test 
+            // if table is broken, Engine is reported as null, so one more test
             if ($each_table['TABLE_TYPE'] == 'VIEW') {
                 // countRecords() takes care of $cfg['MaxExactCountViews']
                 $each_table['TABLE_ROWS'] = PMA_Table::countRecords($db,
-                    $each_table['TABLE_NAME'], $return = true, $force_exact = true,
+                    $each_table['TABLE_NAME'], $force_exact = true,
                     $is_view = true);
                 $table_is_view = true;
             }
@@ -357,7 +214,10 @@ foreach ($tables as $keyname => $each_table) {
                 $unit          =  '';
             }
     } // end switch
-    $sum_entries += $each_table['TABLE_ROWS'];
+
+    if (! PMA_Table::isMerge($db, $each_table['TABLE_NAME'])) {
+        $sum_entries += $each_table['TABLE_ROWS'];
+    }
 
     if (isset($each_table['Collation'])) {
         $collation = '<dfn title="'
@@ -397,20 +257,25 @@ foreach ($tables as $keyname => $each_table) {
     if ($each_table['TABLE_ROWS'] > 0) {
         $browse_table = '<a href="sql.php?' . $tbl_url_query . '&amp;pos=0">' . $titles['Browse'] . '</a>';
         $search_table = '<a href="tbl_select.php?' . $tbl_url_query . '">' . $titles['Search'] . '</a>';
+        $browse_table_label = '<a href="sql.php?' . $tbl_url_query . '&amp;pos=0">' . $truename . '</a>';
     } else {
         $browse_table = $titles['NoBrowse'];
         $search_table = $titles['NoSearch'];
+        $browse_table_label = '<a href="tbl_structure.php?' . $tbl_url_query . '">' . $truename . '</a>';
     }
 
     if (! $db_is_information_schema) {
         if (! empty($each_table['TABLE_ROWS'])) {
-            $empty_table = '<a href="sql.php?' . $tbl_url_query
+            $empty_table = '<a ';
+            if ($GLOBALS['cfg']['AjaxEnable']) {
+                $empty_table .= 'class="truncate_table_anchor"';
+            }
+            $empty_table .= ' href="sql.php?' . $tbl_url_query
                  . '&amp;sql_query=';
             $empty_table .= urlencode('TRUNCATE ' . PMA_backquote($each_table['TABLE_NAME']))
-                 . '&amp;zero_rows='
-                 . urlencode(sprintf($strTableHasBeenEmptied, htmlspecialchars($each_table['TABLE_NAME'])))
-                 . '" onclick="return confirmLink(this, \'TRUNCATE ';
-            $empty_table .= PMA_jsFormat($each_table['TABLE_NAME']) . '\')">' . $titles['Empty'] . '</a>';
+                 . '&amp;message_to_show='
+                 . urlencode(sprintf(__('Table %s has been emptied'), htmlspecialchars($each_table['TABLE_NAME'])))
+                 .'">' . $titles['Empty'] . '</a>';
         } else {
             $empty_table = $titles['NoEmpty'];
         }
@@ -418,10 +283,19 @@ foreach ($tables as $keyname => $each_table) {
             . ($table_is_view ? 'VIEW' : 'TABLE')
             . ' ' . PMA_backquote($each_table['TABLE_NAME']);
         $drop_message = sprintf(
-            $table_is_view ? $strViewHasBeenDropped : $strTableHasBeenDropped,
+            $table_is_view ? __('View %s has been dropped') : __('Table %s has been dropped'),
             str_replace(' ', '&nbsp;', htmlspecialchars($each_table['TABLE_NAME'])));
     }
 
+    $tracking_icon = '';
+    if (PMA_Tracker::isActive()) {
+        if (PMA_Tracker::isTracked($GLOBALS["db"], $truename)) {
+            $tracking_icon = '<a href="tbl_tracking.php?' . $url_query.'&amp;table=' . $truename . '"><img class="icon" width="14" height="14" src="' . $pmaThemeImage . 'eye.png" alt="' . __('Tracking is active.') . '" title="' . __('Tracking is active.') . '" /></a>';
+        } elseif (PMA_Tracker::getVersion($GLOBALS["db"], $truename) > 0) {
+            $tracking_icon = '<a href="tbl_tracking.php?' . $url_query . '&amp;table=' . $truename . '"><img class="icon" width="14" height="14" src="' . $pmaThemeImage . 'eye_grey.png" alt="' . __('Tracking is not active.') . '" title="' . __('Tracking is not active.') . '" /></a>';
+        }
+    }
+
     if ($num_columns > 0 && $num_tables > $num_columns
       && (($row_count % $num_columns) == 0)) {
         $row_count = 1;
@@ -431,7 +305,38 @@ foreach ($tables as $keyname => $each_table) {
 </tbody>
 </table>
         <?php
-        PMA_TableHeader();
+        PMA_TableHeader(false, $server_slave_status);
+    }
+
+    $ignored = false;
+    $do = false;
+
+    if ($server_slave_status) {
+        ////////////////////////////////////////////////////////////////
+
+        if ((strlen(array_search($truename, $server_slave_Do_Table)) > 0)
+            || (strlen(array_search($db, $server_slave_Do_DB)) > 0)
+            || (count($server_slave_Do_DB) == 1 && count($server_slave_Ignore_DB) == 1)
+        ) {
+            $do = true;
+        }
+        foreach ($server_slave_Wild_Do_Table as $db_table) {
+            $table_part = PMA_extract_db_or_table($db_table, 'table');
+            if (($db == PMA_extract_db_or_table($db_table, 'db')) && (preg_match("@^" . substr($table_part, 0, strlen($table_part) - 1) . "@", $truename))) {
+                $do = true;
+            }
+        }
+        ////////////////////////////////////////////////////////////////////
+        if ((strlen(array_search($truename, $server_slave_Ignore_Table)) > 0)  || (strlen(array_search($db, $server_slave_Ignore_DB)) > 0)) {
+            $ignored = true;
+        }
+        foreach ($server_slave_Wild_Ignore_Table as $db_table) {
+            $table_part = PMA_extract_db_or_table($db_table, 'table');
+            if (($db == PMA_extract_db_or_table($db_table)) && (preg_match("@^" . substr($table_part, 0, strlen($table_part) - 1) . "@", $truename))) {
+                $ignored = true;
+            }
+        }
+        unset($table_part);
     }
     ?>
 <tr class="<?php echo $odd_row ? 'odd' : 'even'; $odd_row = ! $odd_row; ?>">
@@ -439,9 +344,10 @@ foreach ($tables as $keyname => $each_table) {
         <input type="checkbox" name="selected_tbl[]"
             value="<?php echo htmlspecialchars($each_table['TABLE_NAME']); ?>"
             id="checkbox_tbl_<?php echo $i; ?>"<?php echo $checked; ?> /></td>
-    <th><label for="checkbox_tbl_<?php echo $i; ?>"
-            title="<?php echo $alias; ?>"><?php echo $truename; ?></label>
+    <th><?php echo $browse_table_label; ?>
+        <?php echo (! empty($tracking_icon) ? $tracking_icon : ''); ?>
     </th>
+   <?php if ($server_slave_status) { ?><td align="center"><?php echo $ignored ? ' <img class="icon" src="' . $pmaThemeImage . 's_cancel.png" width="16" height="16"  alt="NOT REPLICATED" />' : ''. $do ? ' <img class="icon" src="' . $pmaThemeImage . 's_success.png" width="16" height="16"  alt="REPLICATED" />' : ''; ?></td><?php } ?>
     <td align="center"><?php echo $browse_table; ?></td>
     <td align="center">
         <a href="tbl_structure.php?<?php echo $tbl_url_query; ?>">
@@ -453,11 +359,10 @@ foreach ($tables as $keyname => $each_table) {
             <?php echo $titles['Insert']; ?></a></td>
     <td align="center"><?php echo $empty_table; ?></td>
     <td align="center">
-        <a href="sql.php?<?php echo $tbl_url_query;
+    <a <?php echo ($GLOBALS['cfg']['AjaxEnable'] ? 'class="drop_table_anchor"' : ''); ?> href="sql.php?<?php echo $tbl_url_query;
             ?>&amp;reload=1&amp;purge=1&amp;sql_query=<?php
-            echo urlencode($drop_query); ?>&amp;zero_rows=<?php
-            echo urlencode($drop_message); ?>"
-            onclick="return confirmLink(this, '<?php echo PMA_jsFormat($drop_query, false); ?>')">
+            echo urlencode($drop_query); ?>&amp;message_to_show=<?php
+            echo urlencode($drop_message); ?>" >
             <?php echo $titles['Drop']; ?></a></td>
     <?php } // end if (! $db_is_information_schema)
 
@@ -471,7 +376,7 @@ foreach ($tables as $keyname => $each_table) {
             if ($each_table['TABLE_ROWS'] >= $GLOBALS['cfg']['MaxExactCountViews']){
                 $row_count_pre = '~';
                 $sum_row_count_pre = '~';
-                $show_superscript = PMA_showHint(PMA_sanitize(sprintf($strViewHasAtLeast, '[a@./Documentation.html#cfg_MaxExactCountViews@_blank]', '[/a]')));
+                $show_superscript = PMA_showHint(PMA_sanitize(sprintf(__('This view has at least this number of rows. Please refer to %sdocumentation%s.'), '[a@./Documentation.html#cfg_MaxExactCountViews@_blank]', '[/a]')));
             }
         } elseif($each_table['ENGINE'] == 'InnoDB' && (! $each_table['COUNTED'])) {
             // InnoDB table: we did not get an accurate row count
@@ -483,32 +388,32 @@ foreach ($tables as $keyname => $each_table) {
             $show_superscript = '';
         }
     ?>
-    <td class="value"><?php echo $row_count_pre . PMA_formatNumber($each_table['TABLE_ROWS'], 0) . $show_superscript; ?></td>
+    <td class="value tbl_rows"><?php echo $row_count_pre . PMA_formatNumber($each_table['TABLE_ROWS'], 0) . $show_superscript; ?></td>
         <?php if (!($cfg['PropertiesNumColumns'] > 1)) { ?>
-    <td nowrap="nowrap"><?php echo ($table_is_view ? $strView : $each_table['ENGINE']); ?></td>
+    <td nowrap="nowrap"><?php echo ($table_is_view ? __('View') : $each_table['ENGINE']); ?></td>
             <?php if (isset($collation)) { ?>
     <td nowrap="nowrap"><?php echo $collation ?></td>
             <?php } ?>
         <?php } ?>
 
         <?php if ($is_show_stats) { ?>
-    <td class="value"><a
+    <td class="value tbl_size"><a
         href="tbl_structure.php?<?php echo $tbl_url_query; ?>#showusage"
         ><?php echo $formatted_size . ' ' . $unit; ?></a></td>
     <td class="value"><?php echo $overhead; ?></td>
         <?php } // end if ?>
     <?php } elseif ($table_is_view) { ?>
     <td class="value">-</td>
-    <td><?php echo $strView; ?></td>
+    <td><?php echo __('View'); ?></td>
     <td>---</td>
         <?php if ($is_show_stats) { ?>
     <td class="value">-</td>
     <td class="value">-</td>
         <?php } ?>
     <?php } else { ?>
-    <td colspan="<?php echo ($structure_tbl_col_cnt - ($db_is_information_schema ? 5 : 8)) ?>"
+    <td colspan="<?php echo ($colspan_for_structure - ($db_is_information_schema ? 5 : 8)) ?>"
         align="center">
-        <?php echo $strInUse; ?></td>
+        <?php echo __('in use'); ?></td>
     <?php } // end if (isset($each_table['TABLE_ROWS'])) else ?>
 </tr>
     <?php
@@ -522,32 +427,37 @@ if ($is_show_stats) {
 }
 ?>
 </tbody>
-<tbody>
+<tbody id="tbl_summary_row">
 <tr><th></th>
     <th align="center" nowrap="nowrap">
         <?php
             // for blobstreaming - if the number of tables is 0, set tableReductionCount to 0
-            // (we don't want negative numbers here) - rajk
+            // (we don't want negative numbers here)
             if ($num_tables == 0)
                 $tableReductionCount = 0;
 
-            echo sprintf($strTables, PMA_formatNumber($num_tables - $tableReductionCount, 0));
+            echo sprintf(_ngettext('%s table', '%s tables', $num_tables - $tableReductionCount), PMA_formatNumber($num_tables - $tableReductionCount, 0));
         ?>
     </th>
+    <?php
+        if ($server_slave_status) {
+            echo '    <th>' . __('Replication') . '</th>' . "\n";
+        }
+    ?>
     <th colspan="<?php echo ($db_is_information_schema ? 3 : 6) ?>" align="center">
-        <?php echo $strSum; ?></th>
-    <th class="value"><?php echo $sum_row_count_pre . PMA_formatNumber($sum_entries, 0); ?></th>
+        <?php echo __('Sum'); ?></th>
+    <th class="value tbl_rows"><?php echo $sum_row_count_pre . PMA_formatNumber($sum_entries, 0); ?></th>
 <?php
 if (!($cfg['PropertiesNumColumns'] > 1)) {
     $default_engine = PMA_DBI_get_default_engine();
     echo '    <th align="center">' . "\n"
        . '        <dfn title="'
-       . sprintf($strDefaultEngine, $default_engine) . '">' .$default_engine . '</dfn></th>' . "\n";
+       . sprintf(__('%s is the default storage engine on this MySQL server.'), $default_engine) . '">' .$default_engine . '</dfn></th>' . "\n";
     // we got a case where $db_collation was empty
     echo '    <th align="center">' . "\n";
     if (! empty($db_collation)) {
         echo '        <dfn title="'
-            . PMA_getCollationDescr($db_collation) . ' (' . $strDefault . ')">' . $db_collation
+            . PMA_getCollationDescr($db_collation) . ' (' . __('Default') . ')">' . $db_collation
             . '</dfn>';
     }
     echo '</th>';
@@ -555,7 +465,7 @@ if (!($cfg['PropertiesNumColumns'] > 1)) {
 
 if ($is_show_stats) {
     ?>
-    <th class="value"><?php echo $sum_formatted . ' ' . $unit; ?></th>
+    <th class="value tbl_size"><?php echo $sum_formatted . ' ' . $unit; ?></th>
     <th class="value"><?php echo $overhead_formatted . ' ' . $overhead_unit; ?></th>
     <?php
 }
@@ -570,39 +480,44 @@ if ($is_show_stats) {
 $checkall_url = 'db_structure.php?' . PMA_generate_common_url($db);
 ?>
 <img class="selectallarrow" src="<?php echo $pmaThemeImage .'arrow_'.$text_dir.'.png'; ?>"
-    width="38" height="22" alt="<?php echo $strWithChecked; ?>" />
+    width="38" height="22" alt="<?php echo __('With selected:'); ?>" />
 <a href="<?php echo $checkall_url; ?>&amp;checkall=1"
     onclick="if (markAllRows('tablesForm')) return false;">
-    <?php echo $strCheckAll; ?></a>
+    <?php echo __('Check All'); ?></a>
 /
 <a href="<?php echo $checkall_url; ?>"
     onclick="if (unMarkAllRows('tablesForm')) return false;">
-    <?php echo $strUncheckAll; ?></a>
+    <?php echo __('Uncheck All'); ?></a>
 <?php if ($overhead_check != '') { ?>
 /
 <a href="#" onclick="unMarkAllRows('tablesForm');
     <?php echo $overhead_check; ?> return false;">
-    <?php echo $strCheckOverhead; ?></a>
+    <?php echo __('Check tables having overhead'); ?></a>
 <?php } ?>
 
 <select name="submit_mult" onchange="this.form.submit();" style="margin: 0 3em 0 3em;">
 <?php
-echo '    <option value="' . $strWithChecked . '" selected="selected">'
-     . $strWithChecked . '</option>' . "\n";
-echo '    <option value="' . $strEmpty . '" >'
-     . $strEmpty . '</option>' . "\n";
-echo '    <option value="' . $strDrop . '" >'
-     . $strDrop . '</option>' . "\n";
-echo '    <option value="' . $strPrintView . '" >'
-     . $strPrintView . '</option>' . "\n";
-echo '    <option value="' . $strCheckTable . '" >'
-     . $strCheckTable . '</option>' . "\n";
-echo '    <option value="' . $strOptimizeTable . '" >'
-     . $strOptimizeTable . '</option>' . "\n";
-echo '    <option value="' . $strRepairTable . '" >'
-     . $strRepairTable . '</option>' . "\n";
-echo '    <option value="' . $strAnalyzeTable . '" >'
-     . $strAnalyzeTable . '</option>' . "\n";
+echo '    <option value="' . __('With selected:') . '" selected="selected">'
+     . __('With selected:') . '</option>' . "\n";
+echo '    <option value="export" >'
+     . __('Export') . '</option>' . "\n";
+echo '    <option value="print" >'
+    . __('Print view') . '</option>' . "\n";
+
+if (!$db_is_information_schema) {
+    echo '    <option value="empty_tbl" >'
+         . __('Empty') . '</option>' . "\n";
+    echo '    <option value="drop_tbl" >'
+         . __('Drop') . '</option>' . "\n";
+    echo '    <option value="check_tbl" >'
+         . __('Check table') . '</option>' . "\n";
+    echo '    <option value="optimize_tbl" >'
+         . __('Optimize table') . '</option>' . "\n";
+    echo '    <option value="repair_tbl" >'
+         . __('Repair table') . '</option>' . "\n";
+    echo '    <option value="analyze_tbl" >'
+         . __('Analyze table') . '</option>' . "\n";
+}
 ?>
 </select>
 <script type="text/javascript">
@@ -611,7 +526,7 @@ echo '    <option value="' . $strAnalyzeTable . '" >'
 //-->
 </script>
 <noscript>
-    <input type="submit" value="<?php echo $strGo; ?>" />
+    <input type="submit" value="<?php echo __('Go'); ?>" />
 </noscript>
 <?php echo implode("\n", $hidden_fields) . "\n"; ?>
 </div>
@@ -620,6 +535,7 @@ echo '    <option value="' . $strAnalyzeTable . '" >'
 // display again the table list navigator
 PMA_listNavigator($total_num_tables, $pos, $_url_params, 'db_structure.php', 'frame_content', $GLOBALS['cfg']['MaxTableList']);
 ?>
+</div>
 <hr />
 
 <?php
@@ -633,7 +549,6 @@ if (PMA_MYSQL_INT_VERSION > 50100) {
 
 /**
  * Work on the database
- * redesigned 2004-05-08 by mkkeck
  */
 /* DATABASE WORK */
 /* Printable view of a table */
@@ -643,14 +558,14 @@ if ($cfg['PropertiesIconic']) {
      echo '<img class="icon" src="' . $pmaThemeImage
         .'b_print.png" width="16" height="16" alt="" />';
 }
-echo $strPrintView . '</a> ';
+echo __('Print view') . '</a> ';
 
 echo '<a href="./db_datadict.php?' . $url_query . '">';
 if ($cfg['PropertiesIconic']) {
     echo '<img class="icon" src="' . $pmaThemeImage
         .'b_tblanalyse.png" width="16" height="16" alt="" />';
 }
-echo $strDataDict . '</a>';
+echo __('Data Dictionary') . '</a>';
 echo '</p>';
 
 if (empty($db_is_information_schema)) {
@@ -660,5 +575,5 @@ if (empty($db_is_information_schema)) {
 /**
  * Displays the footer
  */
-require_once './libraries/footer.inc.php';
+require './libraries/footer.inc.php';
 ?>
