@@ -2,7 +2,6 @@
 /* vim: set expandtab sw=4 ts=4 sts=4: */
 /**
  * @todo    too much die here, or?
- * @version $Id$
  * @package phpMyAdmin
  */
 
@@ -42,7 +41,15 @@ $compression = false;
 $onserver = false;
 $save_on_server = false;
 $buffer_needed = false;
-if (empty($_REQUEST['asfile'])) {
+
+// Is it a quick or custom export?
+if($_REQUEST['quick_or_custom'] == 'quick') {
+    $quick_export = true;
+} else {
+    $quick_export = false;
+}
+
+if ($_REQUEST['output_format'] == 'astext') {
     $asfile = false;
 } else {
     $asfile = true;
@@ -50,8 +57,12 @@ if (empty($_REQUEST['asfile'])) {
         $compression = $_REQUEST['compression'];
         $buffer_needed = true;
     }
-    if (!empty($_REQUEST['onserver'])) {
-        $onserver = $_REQUEST['onserver'];
+    if (($quick_export && !empty($_REQUEST['quick_export_onserver'])) || (!$quick_export && !empty($_REQUEST['onserver']))) {
+        if($quick_export) {
+            $onserver = $_REQUEST['quick_export_onserver'];
+        } else {
+            $onserver = $_REQUEST['onserver'];
+        }
         // Will we save dump on server?
         $save_on_server = ! empty($cfg['SaveDir']) && $onserver;
     }
@@ -59,8 +70,7 @@ if (empty($_REQUEST['asfile'])) {
 
 // Does export require to be into file?
 if (isset($export_list[$type]['force_file']) && ! $asfile) {
-    $message = PMA_Message::error('strExportMustBeFile');
-    $GLOBALS['js_include'][] = 'functions.js';
+    $message = PMA_Message::error(__('Selected export type has to be saved in file!'));
     require_once './libraries/header.inc.php';
     if ($export_type == 'server') {
         $active_page = 'server_export.php';
@@ -151,7 +161,7 @@ function PMA_exportOutputHandler($line)
                 if ($GLOBALS['save_on_server']) {
                     $write_result = @fwrite($GLOBALS['file_handle'], $dump_buffer);
                     if (!$write_result || ($write_result != strlen($dump_buffer))) {
-                        $GLOBALS['message'] = PMA_Message::error('strNoSpace');
+                        $GLOBALS['message'] = PMA_Message::error(__('Insufficient space to save the file %s.'));
                         $GLOBALS['message']->addParam($save_filename);
                         return false;
                     }
@@ -176,7 +186,7 @@ function PMA_exportOutputHandler($line)
             if ($GLOBALS['save_on_server'] && strlen($line) > 0) {
                 $write_result = @fwrite($GLOBALS['file_handle'], $line);
                 if (!$write_result || ($write_result != strlen($line))) {
-                    $GLOBALS['message'] = PMA_Message::error('strNoSpace');
+                    $GLOBALS['message'] = PMA_Message::error(__('Insufficient space to save the file %s.'));
                     $GLOBALS['message']->addParam($save_filename);
                     return false;
                 }
@@ -207,7 +217,7 @@ if ($what == 'sql') {
 $output_kanji_conversion = function_exists('PMA_kanji_str_conv') && $type != 'xls';
 
 // Do we need to convert charset?
-$output_charset_conversion = $asfile && $cfg['AllowAnywhereRecoding']
+$output_charset_conversion = $asfile && $GLOBALS['PMA_recoding_engine'] != PMA_CHARSET_NONE
     && isset($charset_of_file) && $charset_of_file != $charset
     && $type != 'xls';
 
@@ -246,30 +256,33 @@ if ($asfile) {
     $pma_uri_parts = parse_url($cfg['PmaAbsoluteUri']);
     if ($export_type == 'server') {
         if (isset($remember_template)) {
-            PMA_setCookie('pma_server_filename_template', $filename_template);
+            $GLOBALS['PMA_Config']->setUserValue('pma_server_filename_template',
+                'Export/file_template_server', $filename_template);
         }
-        $filename = str_replace('__SERVER__', $GLOBALS['cfg']['Server']['host'], strftime($filename_template));
     } elseif ($export_type == 'database') {
         if (isset($remember_template)) {
-            PMA_setCookie('pma_db_filename_template', $filename_template);
+            $GLOBALS['PMA_Config']->setUserValue('pma_db_filename_template',
+                'Export/file_template_database', $filename_template);
         }
-        $filename = str_replace('__DB__', $db, str_replace('__SERVER__', $GLOBALS['cfg']['Server']['host'], strftime($filename_template)));
     } else {
         if (isset($remember_template)) {
-            PMA_setCookie('pma_table_filename_template', $filename_template);
+            $GLOBALS['PMA_Config']->setUserValue('pma_table_filename_template',
+                'Export/file_template_table', $filename_template);
         }
-        $filename = str_replace('__TABLE__', $table, str_replace('__DB__', $db, str_replace('__SERVER__', $GLOBALS['cfg']['Server']['host'], strftime($filename_template))));
     }
+    $filename = PMA_expandUserString($filename_template);
 
     // convert filename to iso-8859-1, it is safer
-    if (!(isset($cfg['AllowAnywhereRecoding']) && $cfg['AllowAnywhereRecoding'] )) {
-        $filename = PMA_convert_string($charset, 'iso-8859-1', $filename);
-    } else {
-        $filename = PMA_convert_string($convcharset, 'iso-8859-1', $filename);
-    }
+    $filename = PMA_convert_string($charset, 'iso-8859-1', $filename);
 
     // Grab basic dump extension and mime type
-    $filename  .= '.' . $export_list[$type]['extension'];
+    // Check if the user already added extension; get the substring where the extension would be if it was included
+    $extension_start_pos = strlen($filename) - strlen($export_list[$type]['extension']) - 1;
+    $user_extension = substr($filename, $extension_start_pos, strlen($filename));
+    $required_extension = "." . $export_list[$type]['extension'];
+    if(strtolower($user_extension) != $required_extension) {
+        $filename  .= $required_extension;
+    }
     $mime_type  = $export_list[$type]['mime_type'];
 
     // If dump is going to be compressed, set correct mime_type and add
@@ -290,22 +303,21 @@ if ($asfile) {
 if ($save_on_server) {
     $save_filename = PMA_userDir($cfg['SaveDir']) . preg_replace('@[/\\\\]@', '_', $filename);
     unset($message);
-    if (file_exists($save_filename) && empty($onserverover)) {
-        $message = PMA_Message::error('strFileAlreadyExists');
+    if (file_exists($save_filename) && ((!$quick_export && empty($onserverover)) || ($quick_export && $_REQUEST['quick_export_onserverover'] != 'saveitover'))) {
+        $message = PMA_Message::error(__('File %s already exists on server, change filename or check overwrite option.'));
         $message->addParam($save_filename);
     } else {
         if (is_file($save_filename) && !is_writable($save_filename)) {
-            $message = PMA_Message::error('strNoPermission');
+            $message = PMA_Message::error(__('The web server does not have permission to save the file %s.'));
             $message->addParam($save_filename);
         } else {
             if (!$file_handle = @fopen($save_filename, 'w')) {
-                $message = PMA_Message::error('strNoPermission');
+                $message = PMA_Message::error(__('The web server does not have permission to save the file %s.'));
                 $message->addParam($save_filename);
             }
         }
     }
     if (isset($message)) {
-        $GLOBALS['js_include'][] = 'functions.js';
         require_once './libraries/header.inc.php';
         if ($export_type == 'server') {
             $active_page = 'server_export.php';
@@ -334,7 +346,7 @@ if (!$save_on_server) {
 
         header('Content-Type: ' . $mime_type);
         header('Expires: ' . gmdate('D, d M Y H:i:s') . ' GMT');
-        // lem9: Tested behavior of
+        // Tested behavior of
         //       IE 5.50.4807.2300
         //       IE 6.0.2800.1106 (small glitch, asks twice when I click Open)
         //       IE 6.0.2900.2180
@@ -356,8 +368,7 @@ if (!$save_on_server) {
         if ($export_type == 'database') {
             $num_tables = count($tables);
             if ($num_tables == 0) {
-                $message = PMA_Message::error('strNoTablesFound');
-                $GLOBALS['js_include'][] = 'functions.js';
+                $message = PMA_Message::error(__('No tables found in database.'));
                 require_once './libraries/header.inc.php';
                 $active_page = 'db_export.php';
                 require './db_export.php';
@@ -370,6 +381,32 @@ if (!$save_on_server) {
         unset($backup_cfgServer);
         echo "\n" . '<div align="' . $cell_align_left . '">' . "\n";
         //echo '    <pre>' . "\n";
+
+        /**
+         * Displays a back button with all the $_REQUEST data in the URL (store in a variable to also display after the textarea)
+         */
+         $back_button = '<p>[ <a href="';
+        if ($export_type == 'server') {
+           $back_button .= 'server_export.php?' . PMA_generate_common_url();
+         } elseif ($export_type == 'database') {
+            $back_button .= 'db_export.php?' . PMA_generate_common_url($db);
+        } else {
+            $back_button .= 'tbl_export.php?' . PMA_generate_common_url($db, $table);
+        }
+
+        // Convert the multiple select elements from an array to a string
+        if($export_type == 'server' && isset($_REQUEST['db_select'])) {
+            $_REQUEST['db_select'] = implode(",", $_REQUEST['db_select']);
+        } elseif($export_type == 'database' && isset($_REQUEST['table_select'])) {
+            $_REQUEST['table_select'] = implode(",", $_REQUEST['table_select']);
+        }
+
+        foreach($_REQUEST as $name => $value) {
+            $back_button .= '&' . urlencode($name) . '=' . urlencode($value);
+        }
+        $back_button .= '&repopulate=1">Back</a> ]</p>';
+
+        echo $back_button;
         echo '    <form name="nofunction">' . "\n"
            // remove auto-select for now: there is no way to select
            // only a part of the text; anyway, it should obey
@@ -390,10 +427,9 @@ if (!PMA_exportHeader()) {
 
 // Will we need relation & co. setup?
 $do_relation = isset($GLOBALS[$what . '_relation']);
-$do_comments = isset($GLOBALS[$what . '_comments']);
+$do_comments = isset($GLOBALS[$what . '_include_comments']);
 $do_mime     = isset($GLOBALS[$what . '_mime']);
 if ($do_relation || $do_comments || $do_mime) {
-    require_once './libraries/relation.lib.php';
     $cfgRelation = PMA_getRelationsParam();
 }
 if ($do_mime) {
@@ -422,6 +458,10 @@ if ($export_type == 'server') {
             if (!PMA_exportDBCreate($current_db)) {
                 break 2;
             }
+            if (function_exists('PMA_exportRoutines') && strpos($GLOBALS['sql_structure_or_data'], 'structure') !== false && isset($GLOBALS['sql_procedure_function'])) {
+                PMA_exportRoutines($current_db);
+            }
+
             $tables = PMA_DBI_get_tables($current_db);
             $views = array();
             foreach ($tables as $table) {
@@ -431,7 +471,7 @@ if ($export_type == 'server') {
                 if ($is_view) {
                     $views[] = $table;
                 }
-                if (isset($GLOBALS[$what . '_structure'])) {
+                if ($GLOBALS[$what . '_structure_or_data'] == 'structure' || $GLOBALS[$what . '_structure_or_data'] == 'structure_and_data') {
                     // for a view, export a stand-in definition of the table
                     // to resolve view dependencies
                     if (!PMA_exportStructure($current_db, $table, $crlf, $err_url, $do_relation, $do_comments, $do_mime, $do_dates, $is_view ? 'stand_in' : 'create_table', $export_type)) {
@@ -439,7 +479,7 @@ if ($export_type == 'server') {
                     }
                 }
                 // if this is a view or a merge table, don't export data
-                if (isset($GLOBALS[$what . '_data']) && !($is_view || PMA_Table::isMerge($current_db, $table))) {
+                if (($GLOBALS[$what . '_structure_or_data'] == 'data' || $GLOBALS[$what . '_structure_or_data'] == 'structure_and_data') && !($is_view || PMA_Table::isMerge($current_db, $table))) {
                     $local_query  = 'SELECT * FROM ' . PMA_backquote($current_db) . '.' . PMA_backquote($table);
                     if (!PMA_exportData($current_db, $table, $crlf, $err_url, $local_query)) {
                         break 3;
@@ -447,7 +487,7 @@ if ($export_type == 'server') {
                 }
                 // now export the triggers (needs to be done after the data because
                 // triggers can modify already imported tables)
-                if (isset($GLOBALS[$what . '_structure'])) {
+                if ($GLOBALS[$what . '_structure_or_data'] == 'structure' || $GLOBALS[$what . '_structure_or_data'] == 'structure_and_data') {
                     if (!PMA_exportStructure($current_db, $table, $crlf, $err_url, $do_relation, $do_comments, $do_mime, $do_dates, 'triggers', $export_type)) {
                         break 2;
                     }
@@ -455,7 +495,7 @@ if ($export_type == 'server') {
             }
             foreach($views as $view) {
                 // no data export for a view
-                if (isset($GLOBALS[$what . '_structure'])) {
+                if ($GLOBALS[$what . '_structure_or_data'] == 'structure' || $GLOBALS[$what . '_structure_or_data'] == 'structure_and_data') {
                     if (!PMA_exportStructure($current_db, $view, $crlf, $err_url, $do_relation, $do_comments, $do_mime, $do_dates, 'create_view', $export_type)) {
                         break 3;
                     }
@@ -470,6 +510,11 @@ if ($export_type == 'server') {
     if (!PMA_exportDBHeader($db)) {
         break;
     }
+
+    if (function_exists('PMA_exportRoutines') && strpos($GLOBALS['sql_structure_or_data'], 'structure') !== false && isset($GLOBALS['sql_procedure_function'])) {
+            PMA_exportRoutines($db);
+    }
+
     $i = 0;
     $views = array();
     // $tables contains the choices from the user (via $table_select)
@@ -480,7 +525,7 @@ if ($export_type == 'server') {
         if ($is_view) {
             $views[] = $table;
         }
-        if (isset($GLOBALS[$what . '_structure'])) {
+        if ($GLOBALS[$what . '_structure_or_data'] == 'structure' || $GLOBALS[$what . '_structure_or_data'] == 'structure_and_data') {
             // for a view, export a stand-in definition of the table
             // to resolve view dependencies
             if (!PMA_exportStructure($db, $table, $crlf, $err_url, $do_relation, $do_comments, $do_mime, $do_dates, $is_view ? 'stand_in' : 'create_table', $export_type)) {
@@ -488,7 +533,7 @@ if ($export_type == 'server') {
             }
         }
         // if this is a view or a merge table, don't export data
-        if (isset($GLOBALS[$what . '_data']) && !($is_view || PMA_Table::isMerge($db, $table))) {
+        if (($GLOBALS[$what . '_structure_or_data'] == 'data' || $GLOBALS[$what . '_structure_or_data'] == 'structure_and_data') && !($is_view || PMA_Table::isMerge($db, $table))) {
             $local_query  = 'SELECT * FROM ' . PMA_backquote($db) . '.' . PMA_backquote($table);
             if (!PMA_exportData($db, $table, $crlf, $err_url, $local_query)) {
                 break 2;
@@ -496,7 +541,7 @@ if ($export_type == 'server') {
         }
         // now export the triggers (needs to be done after the data because
         // triggers can modify already imported tables)
-        if (isset($GLOBALS[$what . '_structure'])) {
+        if ($GLOBALS[$what . '_structure_or_data'] == 'structure' || $GLOBALS[$what . '_structure_or_data'] == 'structure_and_data') {
             if (!PMA_exportStructure($db, $table, $crlf, $err_url, $do_relation, $do_comments, $do_mime, $do_dates, 'triggers', $export_type)) {
                 break 2;
             }
@@ -504,7 +549,7 @@ if ($export_type == 'server') {
     }
     foreach ($views as $view) {
         // no data export for a view
-        if (isset($GLOBALS[$what . '_structure'])) {
+        if ($GLOBALS[$what . '_structure_or_data'] == 'structure' || $GLOBALS[$what . '_structure_or_data'] == 'structure_and_data') {
             if (!PMA_exportStructure($db, $view, $crlf, $err_url, $do_relation, $do_comments, $do_mime, $do_dates, 'create_view', $export_type)) {
                 break 2;
             }
@@ -529,7 +574,7 @@ if ($export_type == 'server') {
     }
 
     $is_view = PMA_Table::isView($db, $table);
-    if (isset($GLOBALS[$what . '_structure'])) {
+    if ($GLOBALS[$what . '_structure_or_data'] == 'structure' || $GLOBALS[$what . '_structure_or_data'] == 'structure_and_data') {
         if (!PMA_exportStructure($db, $table, $crlf, $err_url, $do_relation, $do_comments, $do_mime, $do_dates, $is_view ? 'create_view' : 'create_table', $export_type)) {
             break;
         }
@@ -537,7 +582,7 @@ if ($export_type == 'server') {
     // If this is an export of a single view, we have to export data;
     // for example, a PDF report
     // if it is a merge table, no data is exported
-    if (isset($GLOBALS[$what . '_data']) && ! PMA_Table::isMerge($db, $table)) {
+    if (($GLOBALS[$what . '_structure_or_data'] == 'data' || $GLOBALS[$what . '_structure_or_data'] == 'structure_and_data') && ! PMA_Table::isMerge($db, $table)) {
         if (!empty($sql_query)) {
             // only preg_replace if needed
             if (!empty($add_query)) {
@@ -555,7 +600,7 @@ if ($export_type == 'server') {
     }
     // now export the triggers (needs to be done after the data because
     // triggers can modify already imported tables)
-    if (isset($GLOBALS[$what . '_structure'])) {
+    if ($GLOBALS[$what . '_structure_or_data'] == 'structure' || $GLOBALS[$what . '_structure_or_data'] == 'structure_and_data') {
         if (!PMA_exportStructure($db, $table, $crlf, $err_url, $do_relation, $do_comments, $do_mime, $do_dates, 'triggers', $export_type)) {
             break 2;
         }
@@ -572,7 +617,6 @@ if (!PMA_exportFooter()) {
 // End of fake loop
 
 if ($save_on_server && isset($message)) {
-    $GLOBALS['js_include'][] = 'functions.js';
     require_once './libraries/header.inc.php';
     if ($export_type == 'server') {
         $active_page = 'server_export.php';
@@ -624,12 +668,11 @@ if (!empty($asfile)) {
         $write_result = @fwrite($file_handle, $dump_buffer);
         fclose($file_handle);
         if (strlen($dump_buffer) !=0 && (!$write_result || ($write_result != strlen($dump_buffer)))) {
-            $message = new PMA_Message('strNoSpace', PMA_Message::ERROR, $save_filename);
+            $message = new PMA_Message(__('Insufficient space to save the file %s.'), PMA_Message::ERROR, $save_filename);
         } else {
-            $message = new PMA_Message('strDumpSaved', PMA_Message::SUCCESS, $save_filename);
+            $message = new PMA_Message(__('Dump has been saved to file %s.'), PMA_Message::SUCCESS, $save_filename);
         }
 
-        $GLOBALS['js_include'][] = 'functions.js';
         require_once './libraries/header.inc.php';
         if ($export_type == 'server') {
             $active_page = 'server_export.php';
@@ -653,9 +696,11 @@ else {
     /**
      * Close the html tags and add the footers in dump is displayed on screen
      */
-    //echo '    </pre>' . "\n";
     echo '</textarea>' . "\n"
        . '    </form>' . "\n";
+    echo $back_button;
+
+    echo "\n";
     echo '</div>' . "\n";
     echo "\n";
 ?>
@@ -680,6 +725,6 @@ else {
 //]]>
 </script>
 <?php
-    require_once './libraries/footer.inc.php';
+    require './libraries/footer.inc.php';
 } // end if
 ?>
