@@ -3,14 +3,13 @@
 /**
  *
  *
- * @version $Id$
  * @package phpMyAdmin
  */
 
 /**
  * Load vendor configuration.
  */
-require_once('./libraries/vendor_config.php');
+require('./libraries/vendor_config.php');
 
 /**
  * Configuration class
@@ -24,6 +23,11 @@ class PMA_Config
      */
     var $default_source = './libraries/config.default.php';
 
+    /**
+     * @var array   default configuration settings
+     */
+    var $default = array();
+
     /**
      * @var array   configuration settings
      */
@@ -92,7 +96,7 @@ class PMA_Config
      */
     function checkSystem()
     {
-        $this->set('PMA_VERSION', '3.3.9.1');
+        $this->set('PMA_VERSION', '3.4.3.2');
         /**
          * @deprecated
          */
@@ -298,32 +302,6 @@ class PMA_Config
         $this->set('PMA_PHP_STR_VERSION', phpversion());
     }
 
-    /**
-     * re-init object after loading from session file
-     * checks config file for changes and relaods if neccessary
-     */
-    function __wakeup()
-    {
-        if (SKIP_MTIME_CONFIG_CHECK
-          || ! $this->checkConfigSource()
-          || $this->source_mtime !== filemtime($this->getSource())
-          || $this->default_source_mtime !== filemtime($this->default_source)
-          || $this->error_config_file
-          || $this->error_config_default_file) {
-            $this->settings = array();
-            $this->load();
-            $this->checkSystem();
-        }
-
-        // check for https needs to be done everytime,
-        // as https and http uses same session so this info can not be stored
-        // in session
-        $this->checkIsHttps();
-
-        $this->checkCollationConnection();
-        $this->checkFontsize();
-    }
-
     /**
      * loads default values from default source
      *
@@ -347,6 +325,7 @@ class PMA_Config
         $this->default_server = $cfg['Servers'][1];
         unset($cfg['Servers']);
 
+        $this->default = $cfg;
         $this->settings = PMA_array_merge_recursive($this->settings, $cfg);
 
         $this->error_config_default_file = false;
@@ -356,8 +335,7 @@ class PMA_Config
 
     /**
      * loads configuration from $source, usally the config file
-     * should be called on object creation and from __wakeup if config file
-     * has changed
+     * should be called on object creation
      *
      * @param   string $source  config file
      */
@@ -381,10 +359,10 @@ class PMA_Config
         $old_error_reporting = error_reporting(0);
         if (function_exists('file_get_contents')) {
             $eval_result =
-                eval('?>' . trim(file_get_contents($this->getSource())));
+                eval('?' . '>' . trim(file_get_contents($this->getSource())));
         } else {
             $eval_result =
-                eval('?>' . trim(implode("\n", file($this->getSource()))));
+                eval('?' . '>' . trim(implode("\n", file($this->getSource()))));
         }
         error_reporting($old_error_reporting);
 
@@ -405,9 +383,9 @@ class PMA_Config
             $cfg['DefaultTabDatabase'] = str_replace('_details', '', str_replace('db_details.php', 'db_sql.php', $cfg['DefaultTabDatabase']));
         }
 
-        $this->checkFontsize();
-        //$this->checkPmaAbsoluteUri();
         $this->settings = PMA_array_merge_recursive($this->settings, $cfg);
+        $this->checkPmaAbsoluteUri();
+        $this->checkFontsize();
 
         $this->checkPermissions();
 
@@ -436,6 +414,176 @@ class PMA_Config
         return true;
     }
 
+    /**
+     * Loads user preferences and merges them with current config
+     * must be called after control connection has been estabilished
+     *
+     * @uses $GLOBALS['cfg']
+     * @uses $GLOBALS['collation_connection']
+     * @uses $GLOBALS['lang']
+     * @uses $_SESSION['cache']['server_$server']['config_mtime']
+     * @uses $_SESSION['cache']['server_$server']['userprefs']
+     * @uses $_SESSION['cache']['server_$server']['userprefs_mtime']
+     * @uses $_SESSION['PMA_Theme_Manager']
+     * @uses PMA_apply_userprefs()
+     * @uses PMA_array_merge_recursive()
+     * @uses PMA_load_userprefs()
+     * @return boolean
+     */
+    function loadUserPreferences()
+    {
+        // index.php should load these settings, so that phpmyadmin.css.php
+        // will have everything avaiable in session cache
+        $server = isset($GLOBALS['server'])
+            ? $GLOBALS['server']
+            : (!empty($GLOBALS['cfg']['ServerDefault']) ? $GLOBALS['cfg']['ServerDefault'] : 0);
+        $cache_key = 'server_' . $server;
+        if ($server > 0 && !defined('PMA_MINIMUM_COMMON')) {
+            $config_mtime = max($this->default_source_mtime, $this->source_mtime);
+            // cache user preferences, use database only when needed
+            if (!isset($_SESSION['cache'][$cache_key]['userprefs'])
+                    || $_SESSION['cache'][$cache_key]['config_mtime'] < $config_mtime) {
+                // load required libraries
+                require_once './libraries/user_preferences.lib.php';
+                $prefs = PMA_load_userprefs();
+                $_SESSION['cache'][$cache_key]['userprefs'] = PMA_apply_userprefs($prefs['config_data']);
+                $_SESSION['cache'][$cache_key]['userprefs_mtime'] = $prefs['mtime'];
+                $_SESSION['cache'][$cache_key]['userprefs_type'] = $prefs['type'];
+                $_SESSION['cache'][$cache_key]['config_mtime'] = $config_mtime;
+            }
+        } else if ($server == 0 || !isset($_SESSION['cache'][$cache_key]['userprefs'])) {
+            $this->set('user_preferences', false);
+            return;
+        }
+        $config_data = $_SESSION['cache'][$cache_key]['userprefs'];
+        // type is 'db' or 'session'
+        $this->set('user_preferences', $_SESSION['cache'][$cache_key]['userprefs_type']);
+        $this->set('user_preferences_mtime', $_SESSION['cache'][$cache_key]['userprefs_mtime']);
+
+        // backup some settings
+        $org_fontsize = $this->settings['fontsize'];
+        // load config array
+        $this->settings = PMA_array_merge_recursive($this->settings, $config_data);
+        $GLOBALS['cfg'] = PMA_array_merge_recursive($GLOBALS['cfg'], $config_data);
+        if (defined('PMA_MINIMUM_COMMON')) {
+            return;
+        }
+
+        // settings below start really working on next page load, but
+        // changes are made only in index.php so everything is set when
+        // in frames
+
+        // save theme
+        $tmanager = $_SESSION['PMA_Theme_Manager'];
+        if ($tmanager->getThemeCookie() || isset($_REQUEST['set_theme'])) {
+            if ((!isset($config_data['ThemeDefault']) && $tmanager->theme->getId() != 'original')
+                    || isset($config_data['ThemeDefault']) && $config_data['ThemeDefault'] != $tmanager->theme->getId()) {
+                // new theme was set in common.inc.php
+                $this->setUserValue(null, 'ThemeDefault', $tmanager->theme->getId(), 'original');
+            }
+        } else {
+            // no cookie - read default from settings
+            if ($this->settings['ThemeDefault'] != $tmanager->theme->getId()
+                    && $tmanager->checkTheme($this->settings['ThemeDefault'])) {
+                $tmanager->setActiveTheme($this->settings['ThemeDefault']);
+                $tmanager->setThemeCookie();
+            }
+        }
+
+        // save font size
+        if ((!isset($config_data['fontsize']) && $org_fontsize != '82%')
+                || isset($config_data['fontsize']) && $org_fontsize != $config_data['fontsize']) {
+            $this->setUserValue(null, 'fontsize', $org_fontsize, '82%');
+        }
+
+        // save language
+        if (isset($_COOKIE['pma_lang']) || isset($_POST['lang'])) {
+            if ((!isset($config_data['lang']) && $GLOBALS['lang'] != 'en')
+                    || isset($config_data['lang']) && $GLOBALS['lang'] != $config_data['lang']) {
+                $this->setUserValue(null, 'lang', $GLOBALS['lang'], 'en');
+            }
+        } else {
+            // read language from settings
+            if (isset($config_data['lang']) && PMA_langSet($config_data['lang'])) {
+                $this->setCookie('pma_lang', $GLOBALS['lang']);
+            }
+        }
+
+        // save connection collation
+        if (isset($_COOKIE['pma_collation_connection']) || isset($_POST['collation_connection'])) {
+            if ((!isset($config_data['collation_connection']) && $GLOBALS['collation_connection'] != 'utf8_general_ci')
+                    || isset($config_data['collation_connection']) && $GLOBALS['collation_connection'] != $config_data['collation_connection']) {
+                $this->setUserValue(null, 'collation_connection', $GLOBALS['collation_connection'], 'utf8_general_ci');
+            }
+        } else {
+            // read collation from settings
+            if (isset($config_data['collation_connection'])) {
+                $GLOBALS['collation_connection'] = $config_data['collation_connection'];
+                $this->setCookie('pma_collation_connection', $GLOBALS['collation_connection']);
+            }
+        }
+    }
+
+    /**
+     * Sets config value which is stored in user preferences (if available) or in a cookie.
+     *
+     * If user preferences are not yet initialized, option is applied to global config and
+     * added to a update queue, which is processed by {@link loadUserPreferences()}
+     *
+     * @uses $GLOBALS['cfg']
+     * @uses PMA_array_read()
+     * @uses PMA_array_write()
+     * @uses PMA_persist_option()
+     * @param string $cookie_name can be null
+     * @param string $cfg_path
+     * @param mixed  $new_cfg_value
+     * @param mixed  $default_value
+     */
+    function setUserValue($cookie_name, $cfg_path, $new_cfg_value, $default_value = null)
+    {
+        // use permanent user preferences if possible
+        $prefs_type = $this->get('user_preferences');
+        if ($prefs_type) {
+            require_once './libraries/user_preferences.lib.php';
+            if ($default_value === null) {
+                $default_value = PMA_array_read($cfg_path, $this->default);
+            }
+            PMA_persist_option($cfg_path, $new_cfg_value, $default_value);
+        }
+        if ($prefs_type != 'db' && $cookie_name) {
+            // fall back to cookies
+            if ($default_value === null) {
+                $default_value = PMA_array_read($cfg_path, $this->settings);
+            }
+            $this->setCookie($cookie_name, $new_cfg_value, $default_value);
+        }
+        PMA_array_write($cfg_path, $GLOBALS['cfg'], $new_cfg_value);
+        PMA_array_write($cfg_path, $this->settings, $new_cfg_value);
+    }
+
+    /**
+     * Reads value stored by {@link setUserValue()}
+     *
+     * @param string $cookie_name
+     * @param mixed $cfg_value
+     * @return mixed
+     */
+    function getUserValue($cookie_name, $cfg_value)
+    {
+        $cookie_exists = isset($_COOKIE) && !empty($_COOKIE[$cookie_name]);
+        $prefs_type = $this->get('user_preferences');
+        if ($prefs_type == 'db') {
+            // permanent user preferences value exists, remove cookie
+            if ($cookie_exists) {
+                $this->removeCookie($cookie_name);
+            }
+        } else if ($cookie_exists) {
+            return $_COOKIE[$cookie_name];
+        }
+        // return value from $cfg array
+        return $cfg_value;
+    }
+
     /**
      * set source
      * @param   string  $source
@@ -554,7 +702,21 @@ class PMA_Config
      */
     function getThemeUniqueValue()
     {
-        return intval((null !== $_SESSION['PMA_Config']->get('fontsize') ? $_SESSION['PMA_Config']->get('fontsize') : (isset($_COOKIE['pma_fontsize']) ? $_COOKIE['pma_fontsize'] : 0))) + ($this->source_mtime + $this->default_source_mtime + $_SESSION['PMA_Theme']->mtime_info + $_SESSION['PMA_Theme']->filesize_info) . (isset($_SESSION['tmp_user_values']['custom_color']) ? substr($_SESSION['tmp_user_values']['custom_color'],1,6) : '');
+        if (null !== $this->get('fontsize')) {
+            $fontsize = intval($this->get('fontsize'));
+        } elseif (isset($_COOKIE['pma_fontsize'])) {
+            $fontsize = intval($_COOKIE['pma_fontsize']);
+        } else {
+            $fontsize = 0;
+        }
+        return (
+            $fontsize +
+            $this->source_mtime +
+            $this->default_source_mtime +
+            $this->get('user_preferences_mtime') +
+            $_SESSION['PMA_Theme']->mtime_info +
+            $_SESSION['PMA_Theme']->filesize_info)
+            . (isset($_SESSION['tmp_user_values']['custom_color']) ? substr($_SESSION['tmp_user_values']['custom_color'],1,6) : '');
     }
 
     /**
@@ -567,13 +729,9 @@ class PMA_Config
         // Setup a default value to let the people and lazy sysadmins work anyway,
         // they'll get an error if the autodetect code doesn't work
         $pma_absolute_uri = $this->get('PmaAbsoluteUri');
-        $is_https = $this->get('is_https');
+        $is_https = $this->detectHttps();
 
-        if (strlen($pma_absolute_uri) < 5
-            // needed to catch http/https switch
-            || ($is_https && substr($pma_absolute_uri, 0, 6) != 'https:')
-            || (!$is_https && substr($pma_absolute_uri, 0, 5) != 'http:')
-        ) {
+        if (strlen($pma_absolute_uri) < 5) {
             $url = array();
 
             // At first we try to parse REQUEST_URI, it might contain full URL
@@ -709,9 +867,7 @@ class PMA_Config
             if (substr($pma_absolute_uri, 0, 7) != 'http://'
               && substr($pma_absolute_uri, 0, 8) != 'https://') {
                 $pma_absolute_uri =
-                    (PMA_getenv('HTTPS') && strtolower(PMA_getenv('HTTPS')) != 'off'
-                        ? 'https'
-                        : 'http')
+                    ($is_https ? 'https' : 'http')
                     . ':' . (substr($pma_absolute_uri, 0, 2) == '//' ? '' : '//')
                     . $pma_absolute_uri;
             }
@@ -741,16 +897,16 @@ class PMA_Config
      * @uses    function_exists()
      * @uses    PMA_Config::set()
      * @uses    PMA_Config::get()
-     * @uses    PMA_setCookie()
+     * @uses    PMA_Config::setCookie()
      */
     function checkFontsize()
     {
         $new_fontsize = '';
 
-        if (isset($_GET['fontsize'])) {
-            $new_fontsize = $_GET['fontsize'];
-        } elseif (isset($_POST['fontsize'])) {
-            $new_fontsize = $_POST['fontsize'];
+        if (isset($_GET['set_fontsize'])) {
+            $new_fontsize = $_GET['set_fontsize'];
+        } elseif (isset($_POST['set_fontsize'])) {
+            $new_fontsize = $_POST['set_fontsize'];
         } elseif (isset($_COOKIE['pma_fontsize'])) {
             $new_fontsize = $_COOKIE['pma_fontsize'];
         }
@@ -763,9 +919,7 @@ class PMA_Config
             $this->set('fontsize', '82%');
         }
 
-        if (function_exists('PMA_setCookie')) {
-            PMA_setCookie('pma_fontsize', $this->get('fontsize'), '82%');
-        }
+        $this->setCookie('pma_fontsize', $this->get('fontsize'), '82%');
     }
 
     /**
@@ -812,13 +966,39 @@ class PMA_Config
      */
     function checkIsHttps()
     {
-        $this->set('is_https', PMA_Config::isHttps());
+        $this->set('is_https', $this->isHttps());
     }
 
     /**
      * @static
      */
-    static public function isHttps()
+    public function isHttps()
+    {
+        static $is_https = null;
+
+        if (null !== $is_https) {
+            return $is_https;
+        }
+
+        $url = parse_url($this->get('PmaAbsoluteUri'));
+
+        if (isset($url['scheme'])
+          && $url['scheme'] == 'https') {
+            $is_https = true;
+        } else {
+            $is_https = false;
+        }
+
+        return $is_https;
+    }
+
+    /**
+     * Detects whether https appears to be used.
+     *
+     * Please note that this just detects what we see, so
+     * it completely ignores things like reverse proxies.
+     */
+    function detectHttps()
     {
         $is_https = false;
 
@@ -861,13 +1041,13 @@ class PMA_Config
      */
     function checkCookiePath()
     {
-        $this->set('cookie_path', PMA_Config::getCookiePath());
+        $this->set('cookie_path', $this->getCookiePath());
     }
 
     /**
      * @static
      */
-    static public function getCookiePath()
+    public function getCookiePath()
     {
         static $cookie_path = null;
 
@@ -875,38 +1055,9 @@ class PMA_Config
             return $cookie_path;
         }
 
-        $url = '';
+        $parsed_url = parse_url($this->get('PmaAbsoluteUri'));
 
-        /**
-         * REQUEST_URI contains PATH_INFO too, this is not what we want
-         * script-php/pathinfo/
-        if (PMA_getenv('REQUEST_URI')) {
-            $url = PMA_getenv('REQUEST_URI');
-        }
-         */
-
-        // If we don't have path
-        if (empty($url)) {
-            if ($GLOBALS['PMA_PHP_SELF']) {
-                // PHP_SELF in CGI often points to cgi executable, so use it
-                // as last choice
-                $url = $GLOBALS['PMA_PHP_SELF'];
-            // on IIS with PHP-CGI:
-            } elseif (PMA_getenv('SCRIPT_NAME')) {
-                $url = PMA_getenv('SCRIPT_NAME');
-            }
-        }
-
-        /**
-         * REQUEST_URI contains PATH_INFO too, this is not what we want
-         * script-php/pathinfo/
-        $parsed_url = @parse_url($_SERVER['REQUEST_URI']); // produces E_WARNING if it cannot get parsed, e.g. '/foobar:/'
-        if ($parsed_url === false) {
-         */
-            $parsed_url = array('path' => $url);
-        //}
-
-        $cookie_path   = substr($parsed_url['path'], 0, strrpos($parsed_url['path'], '/'))  . '/';
+        $cookie_path   = $parsed_url['path'];
 
         return $cookie_path;
     }
@@ -1016,17 +1167,16 @@ class PMA_Config
     /**
      * returns html selectbox for font sizes
      *
-     * @uses    $_SESSION['PMA_Config']
+     * @uses    $GLOBALS['PMA_Config']
      * @uses    PMA_Config::get()
      * @uses    PMA_Config::_getFontsizeOptions()
-     * @uses    $GLOBALS['strFontSize']
      * @static
      * @param   string  $current_size   currently slected font size with unit
      * @return  string  html selectbox
      */
     static protected function _getFontsizeSelection()
     {
-        $current_size = $_SESSION['PMA_Config']->get('fontsize');
+        $current_size = $GLOBALS['PMA_Config']->get('fontsize');
         // for the case when there is no config file (this is supported)
         if (empty($current_size)) {
             if (isset($_COOKIE['pma_fontsize'])) {
@@ -1037,8 +1187,8 @@ class PMA_Config
         }
         $options = PMA_Config::_getFontsizeOptions($current_size);
 
-        $return = '<label for="select_fontsize">' . $GLOBALS['strFontSize'] . ':</label>' . "\n";
-        $return .= '<select name="fontsize" id="select_fontsize" onchange="this.form.submit();">' . "\n";
+        $return = '<label for="select_fontsize">' . __('Font size') . ':</label>' . "\n";
+        $return .= '<select name="set_fontsize" id="select_fontsize" onchange="this.form.submit();">' . "\n";
         foreach ($options as $option) {
             $return .= '<option value="' . $option . '"';
             if ($option == $current_size) {
@@ -1056,7 +1206,6 @@ class PMA_Config
      *
      * @uses    PMA_generate_common_hidden_inputs()
      * @uses    PMA_Config::_getFontsizeSelection()
-     * @uses    $GLOBALS['strGo']
      * @static
      * @param   string  $current_size   currently slected font size with unit
      * @return  string  html selectbox
@@ -1068,9 +1217,77 @@ class PMA_Config
             . PMA_generate_common_hidden_inputs() . "\n"
             . PMA_Config::_getFontsizeSelection() . "\n"
             . '<noscript>' . "\n"
-            . '<input type="submit" value="' . $GLOBALS['strGo'] . '" />' . "\n"
+            . '<input type="submit" value="' . __('Go') . '" />' . "\n"
             . '</noscript>' . "\n"
             . '</form>';
     }
+
+    /**
+     * removes cookie
+     *
+     * @uses    PMA_Config::isHttps()
+     * @uses    PMA_Config::getCookiePath()
+     * @uses    setcookie()
+     * @uses    time()
+     * @param   string  $cookie     name of cookie to remove
+     * @return  boolean result of setcookie()
+     */
+    function removeCookie($cookie)
+    {
+        return setcookie($cookie, '', time() - 3600,
+            $this->getCookiePath(), '', $this->isHttps());
+    }
+
+    /**
+     * sets cookie if value is different from current cokkie value,
+     * or removes if value is equal to default
+     *
+     * @uses    PMA_Config::isHttps()
+     * @uses    PMA_Config::getCookiePath()
+     * @uses    $_COOKIE
+     * @uses    PMA_Config::removeCookie()
+     * @uses    setcookie()
+     * @uses    time()
+     * @param   string  $cookie     name of cookie to remove
+     * @param   mixed   $value      new cookie value
+     * @param   string  $default    default value
+     * @param   int     $validity   validity of cookie in seconds (default is one month)
+     * @param   bool    $httponlt   whether cookie is only for HTTP (and not for scripts)
+     * @return  boolean result of setcookie()
+     */
+    function setCookie($cookie, $value, $default = null, $validity = null, $httponly = true)
+    {
+        if ($validity == null) {
+            $validity = 2592000;
+        }
+        if (strlen($value) && null !== $default && $value === $default) {
+            // default value is used
+            if (isset($_COOKIE[$cookie])) {
+                // remove cookie
+                return $this->removeCookie($cookie);
+            }
+            return false;
+        }
+
+        if (! strlen($value) && isset($_COOKIE[$cookie])) {
+            // remove cookie, value is empty
+            return $this->removeCookie($cookie);
+        }
+
+        if (! isset($_COOKIE[$cookie]) || $_COOKIE[$cookie] !== $value) {
+            // set cookie with new value
+            /* Calculate cookie validity */
+            if ($validity == 0) {
+                $v = 0;
+            } else {
+                $v = time() + $validity;
+            }
+            return setcookie($cookie, $value, $v,
+                $this->getCookiePath(), '', $this->isHttps(), $httponly);
+        }
+
+        // cookie has already $value as value
+        return true;
+    }
 }
 ?>
