@@ -2,7 +2,7 @@
 /**
  * PHPExcel
  *
- * Copyright (c) 2006 - 2009 PHPExcel
+ * Copyright (c) 2006 - 2011 PHPExcel
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -19,37 +19,19 @@
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  *
  * @category   PHPExcel
- * @package    PHPExcel_Style
- * @copyright  Copyright (c) 2006 - 2009 PHPExcel (http://www.codeplex.com/PHPExcel)
- * @license    http://www.gnu.org/licenses/old-licenses/lgpl-2.1.txt	LGPL
- * @version    1.7.0, 2009-08-10
+ * @package	PHPExcel_Style
+ * @copyright  Copyright (c) 2006 - 2011 PHPExcel (http://www.codeplex.com/PHPExcel)
+ * @license	http://www.gnu.org/licenses/old-licenses/lgpl-2.1.txt	LGPL
+ * @version	1.7.6, 2011-02-27
  */
 
 
-/** PHPExcel root directory */
-if (!defined('PHPEXCEL_ROOT')) {
-	/**
-	 * @ignore
-	 */
-	define('PHPEXCEL_ROOT', dirname(__FILE__) . '/../../');
-}
-
-/** PHPExcel_IComparable */
-require_once PHPEXCEL_ROOT . 'PHPExcel/IComparable.php';
-
-/** PHPExcel_Shared_Date */
-require_once PHPEXCEL_ROOT . 'PHPExcel/Shared/Date.php';
-
-/** PHPExcel_Calculation_Functions */
-require_once PHPEXCEL_ROOT . 'PHPExcel/Calculation/Functions.php';
-
-
 /**
  * PHPExcel_Style_NumberFormat
  *
  * @category   PHPExcel
- * @package    PHPExcel_Style
- * @copyright  Copyright (c) 2006 - 2009 PHPExcel (http://www.codeplex.com/PHPExcel)
+ * @package	PHPExcel_Style
+ * @copyright  Copyright (c) 2006 - 2011 PHPExcel (http://www.codeplex.com/PHPExcel)
  */
 class PHPExcel_Style_NumberFormat implements PHPExcel_IComparable
 {
@@ -112,14 +94,14 @@ class PHPExcel_Style_NumberFormat implements PHPExcel_IComparable
 	 *
 	 * @var string
 	 */
-	private $_formatCode;
+	private $_formatCode	=	PHPExcel_Style_NumberFormat::FORMAT_GENERAL;
 
 	/**
 	 * Built-in format Code
 	 *
 	 * @var string
 	 */
-	private $_builtInFormatCode;
+	private $_builtInFormatCode	= 0;
 
 	/**
 	 * Parent Borders
@@ -143,17 +125,13 @@ class PHPExcel_Style_NumberFormat implements PHPExcel_IComparable
 	private $_parent;
 
 	/**
-     * Create a new PHPExcel_Style_NumberFormat
-     */
-    public function __construct($isSupervisor = false)
-    {
-    	// Supervisor?
+	 * Create a new PHPExcel_Style_NumberFormat
+	 */
+	public function __construct($isSupervisor = false)
+	{
+		// Supervisor?
 		$this->_isSupervisor = $isSupervisor;
-
-    	// Initialise values
-    	$this->_formatCode			= PHPExcel_Style_NumberFormat::FORMAT_GENERAL;
-    	$this->_builtInFormatCode	= 0;
-    }
+	}
 
 	/**
 	 * Bind parent. Only used for supervisor
@@ -203,9 +181,9 @@ class PHPExcel_Style_NumberFormat implements PHPExcel_IComparable
 	 *
 	 * @return string E.g. 'A1'
 	 */
-	public function getXSelectedCells()
+	public function getSelectedCells()
 	{
-		return $this->getActiveSheet()->getXSelectedCells();
+		return $this->getActiveSheet()->getSelectedCells();
 	}
 
 	/**
@@ -214,9 +192,9 @@ class PHPExcel_Style_NumberFormat implements PHPExcel_IComparable
 	 *
 	 * @return string E.g. 'A1'
 	 */
-	public function getXActiveCell()
+	public function getActiveCell()
 	{
-		return $this->getActiveSheet()->getXActiveCell();
+		return $this->getActiveSheet()->getActiveCell();
 	}
 
 	/**
@@ -230,25 +208,26 @@ class PHPExcel_Style_NumberFormat implements PHPExcel_IComparable
 		return array('numberformat' => $array);
 	}
 
-    /**
-     * Apply styles from array
-     *
-     * <code>
-     * $objPHPExcel->getActiveSheet()->getStyle('B2')->getNumberFormat()->applyFromArray(
-     * 		array(
-     * 			'code' => PHPExcel_Style_NumberFormat::FORMAT_CURRENCY_EUR_SIMPLE
-     * 		)
-     * );
-     * </code>
-     *
-     * @param	array	$pStyles	Array containing style information
-     * @throws	Exception
-     * @return PHPExcel_Style_NumberFormat
-     */
-	public function applyFromArray($pStyles = null) {
+	/**
+	 * Apply styles from array
+	 *
+	 * <code>
+	 * $objPHPExcel->getActiveSheet()->getStyle('B2')->getNumberFormat()->applyFromArray(
+	 *		array(
+	 *			'code' => PHPExcel_Style_NumberFormat::FORMAT_CURRENCY_EUR_SIMPLE
+	 *		)
+	 * );
+	 * </code>
+	 *
+	 * @param	array	$pStyles	Array containing style information
+	 * @throws	Exception
+	 * @return PHPExcel_Style_NumberFormat
+	 */
+	public function applyFromArray($pStyles = null)
+	{
 		if (is_array($pStyles)) {
 			if ($this->_isSupervisor) {
-				$this->getActiveSheet()->getStyle($this->getXSelectedCells())->applyFromArray($this->getStyleArray($pStyles));
+				$this->getActiveSheet()->getStyle($this->getSelectedCells())->applyFromArray($this->getStyleArray($pStyles));
 			} else {
 				if (array_key_exists('code', $pStyles)) {
 					$this->setFormatCode($pStyles['code']);
@@ -260,83 +239,87 @@ class PHPExcel_Style_NumberFormat implements PHPExcel_IComparable
 		return $this;
 	}
 
-    /**
-     * Get Format Code
-     *
-     * @return string
-     */
-    public function getFormatCode() {
+	/**
+	 * Get Format Code
+	 *
+	 * @return string
+	 */
+	public function getFormatCode()
+	{
 		if ($this->_isSupervisor) {
 			return $this->getSharedComponent()->getFormatCode();
 		}
-    	if ($this->_builtInFormatCode !== false)
-    	{
-    		return self::builtInFormatCode($this->_builtInFormatCode);
-    	}
-    	return $this->_formatCode;
-    }
+		if ($this->_builtInFormatCode !== false)
+		{
+			return self::builtInFormatCode($this->_builtInFormatCode);
+		}
+		return $this->_formatCode;
+	}
 
-    /**
-     * Set Format Code
-     *
-     * @param string $pValue
-     * @return PHPExcel_Style_NumberFormat
-     */
-    public function setFormatCode($pValue = PHPExcel_Style_NumberFormat::FORMAT_GENERAL) {
-        if ($pValue == '') {
-    		$pValue = PHPExcel_Style_NumberFormat::FORMAT_GENERAL;
-    	}
+	/**
+	 * Set Format Code
+	 *
+	 * @param string $pValue
+	 * @return PHPExcel_Style_NumberFormat
+	 */
+	public function setFormatCode($pValue = PHPExcel_Style_NumberFormat::FORMAT_GENERAL)
+	{
+		if ($pValue == '') {
+			$pValue = PHPExcel_Style_NumberFormat::FORMAT_GENERAL;
+		}
 		if ($this->_isSupervisor) {
 			$styleArray = $this->getStyleArray(array('code' => $pValue));
-			$this->getActiveSheet()->getStyle($this->getXSelectedCells())->applyFromArray($styleArray);
+			$this->getActiveSheet()->getStyle($this->getSelectedCells())->applyFromArray($styleArray);
 		} else {
 			$this->_formatCode = $pValue;
 			$this->_builtInFormatCode = self::builtInFormatCodeIndex($pValue);
 		}
 		return $this;
-    }
+	}
 
 	/**
-     * Get Built-In Format Code
-     *
-     * @return int
-     */
-    public function getBuiltInFormatCode() {
+	 * Get Built-In Format Code
+	 *
+	 * @return int
+	 */
+	public function getBuiltInFormatCode()
+	{
 		if ($this->_isSupervisor) {
 			return $this->getSharedComponent()->getBuiltInFormatCode();
 		}
-    	return $this->_builtInFormatCode;
-    }
+		return $this->_builtInFormatCode;
+	}
 
-    /**
-     * Set Built-In Format Code
-     *
-     * @param int $pValue
-     * @return PHPExcel_Style_NumberFormat
-     */
-    public function setBuiltInFormatCode($pValue = 0) {
+	/**
+	 * Set Built-In Format Code
+	 *
+	 * @param int $pValue
+	 * @return PHPExcel_Style_NumberFormat
+	 */
+	public function setBuiltInFormatCode($pValue = 0)
+	{
 
 		if ($this->_isSupervisor) {
 			$styleArray = $this->getStyleArray(array('code' => self::builtInFormatCode($pValue)));
-			$this->getActiveSheet()->getStyle($this->getXSelectedCells())->applyFromArray($styleArray);
+			$this->getActiveSheet()->getStyle($this->getSelectedCells())->applyFromArray($styleArray);
 		} else {
 			$this->_builtInFormatCode = $pValue;
 			$this->_formatCode = self::builtInFormatCode($pValue);
 		}
 		return $this;
-    }
+	}
 
-    /**
-     * Fill built-in format codes
-     */
-    private static function fillBuiltInFormatCodes()
-    {
-    	// Built-in format codes
-    	if (is_null(self::$_builtInFormats)) {
+	/**
+	 * Fill built-in format codes
+	 */
+	private static function fillBuiltInFormatCodes()
+	{
+		// Built-in format codes
+		if (is_null(self::$_builtInFormats)) {
 			self::$_builtInFormats = array();
 
 			// General
-			self::$_builtInFormats[0] = 'General';
+			self::$_builtInFormats[0] = PHPExcel_Style_NumberFormat::FORMAT_GENERAL;
 			self::$_builtInFormats[1] = '0';
 			self::$_builtInFormats[2] = '0.00';
 			self::$_builtInFormats[3] = '#,##0';
@@ -388,102 +371,75 @@ class PHPExcel_Style_NumberFormat implements PHPExcel_IComparable
 
 			// Flip array (for faster lookups)
 			self::$_flippedBuiltInFormats = array_flip(self::$_builtInFormats);
-    	}
-    }
+		}
+	}
 
-    /**
-     * Get built-in format code
-     *
-     * @param	int		$pIndex
-     * @return	string
-     */
-    public static function builtInFormatCode($pIndex) {
-    	// Clean parameter
+	/**
+	 * Get built-in format code
+	 *
+	 * @param	int		$pIndex
+	 * @return	string
+	 */
+	public static function builtInFormatCode($pIndex)
+	{
+		// Clean parameter
 		$pIndex = intval($pIndex);
 
 		// Ensure built-in format codes are available
-    	self::fillBuiltInFormatCodes();
+		self::fillBuiltInFormatCodes();
 
 		// Lookup format code
-		if (array_key_exists($pIndex, self::$_builtInFormats)) {
+		if (isset(self::$_builtInFormats[$pIndex])) {
 			return self::$_builtInFormats[$pIndex];
 		}
 
-    	return '';
-    }
+		return '';
+	}
 
-    /**
-     * Get built-in format code index
-     *
-     * @param	string		$formatCode
-     * @return	int|boolean
-     */
-    public static function builtInFormatCodeIndex($formatCode) {
-    	// Ensure built-in format codes are available
-    	self::fillBuiltInFormatCodes();
+	/**
+	 * Get built-in format code index
+	 *
+	 * @param	string		$formatCode
+	 * @return	int|boolean
+	 */
+	public static function builtInFormatCodeIndex($formatCode)
+	{
+		// Ensure built-in format codes are available
+		self::fillBuiltInFormatCodes();
 
 		// Lookup format code
-		if (array_key_exists($formatCode, self::$_flippedBuiltInFormats)) {
+		if (isset(self::$_flippedBuiltInFormats[$formatCode])) {
 			return self::$_flippedBuiltInFormats[$formatCode];
 		}
 
-    	return false;
-    }
+		return false;
+	}
 
 	/**
 	 * Get hash code
 	 *
 	 * @return string	Hash code
 	 */
-	public function getHashCode() {
+	public function getHashCode()
+	{
 		if ($this->_isSupervisor) {
 			return $this->getSharedComponent()->getHashCode();
 		}
-    	return md5(
-    		  $this->_formatCode
-    		. $this->_builtInFormatCode
-    		. __CLASS__
-    	);
-    }
-
-    /**
-     * Hash index
-     *
-     * @var string
-     */
-    private $_hashIndex;
-
-	/**
-	 * Get hash index
-	 *
-	 * Note that this index may vary during script execution! Only reliable moment is
-	 * while doing a write of a workbook and when changes are not allowed.
-	 *
-	 * @return string	Hash index
-	 */
-	public function getHashIndex() {
-		return $this->_hashIndex;
-	}
-
-	/**
-	 * Set hash index
-	 *
-	 * Note that this index may vary during script execution! Only reliable moment is
-	 * while doing a write of a workbook and when changes are not allowed.
-	 *
-	 * @param string	$value	Hash index
-	 */
-	public function setHashIndex($value) {
-		$this->_hashIndex = $value;
+		return md5(
+			  $this->_formatCode
+			. $this->_builtInFormatCode
+			. __CLASS__
+		);
 	}
 
 	/**
 	 * Implement PHP __clone to create a deep clone, not just a shallow copy.
 	 */
-	public function __clone() {
+	public function __clone()
+	{
 		$vars = get_object_vars($this);
 		foreach ($vars as $key => $value) {
-			if (is_object($value)) {
+			if ((is_object($value)) && ($key != '_parent')) {
 				$this->$key = clone $value;
 			} else {
 				$this->$key = $value;
@@ -491,121 +447,192 @@ class PHPExcel_Style_NumberFormat implements PHPExcel_IComparable
 		}
 	}
 
+	private static $_dateFormatReplacements = array(
+			// first remove escapes related to non-format characters
+			'\\'	=> '',
+			//	12-hour suffix
+			'am/pm'	=> 'A',
+			//	4-digit year
+			'yyyy'	=> 'Y',
+			//	2-digit year
+			'yy'	=> 'y',
+			//	first letter of month - no php equivalent
+			'mmmmm'	=> 'M',
+			//	full month name
+			'mmmm'	=> 'F',
+			//	short month name
+			'mmm'	=> 'M',
+			//	mm is minutes if time or month w/leading zero
+			':mm'	=> ':i',
+			//	month leading zero
+			'mm'	=> 'm',
+			//	month no leading zero
+			'm'		=> 'n',
+			//	full day of week name
+			'dddd'	=> 'l',
+			//	short day of week name
+			'ddd'	=> 'D',
+			//	days leading zero
+			'dd'	=> 'd',
+			//	days no leading zero
+			'd'		=> 'j',
+			//	seconds
+			'ss'	=> 's',
+			//	fractional seconds - no php equivalent
+			'.s'	=> ''
+		);
+	private static $_dateFormatReplacements24 = array(
+			'hh'	=> 'H',
+			'h'		=> 'G'
+		);
+	private static $_dateFormatReplacements12 = array(
+			'hh'	=> 'h',
+			'h'		=> 'g'
+		);
+
 	/**
 	 * Convert a value in a pre-defined format to a PHP string
 	 *
-	 * @param mixed 	$value		Value to format
-	 * @param string 	$format		Format code
+	 * @param mixed	$value		Value to format
+	 * @param string	$format		Format code
+	 * @param array		$callBack	Callback function for additional formatting of string
 	 * @return string	Formatted string
 	 */
-	public static function toFormattedString($value = '', $format = '') {
-		// For now we do not treat strings although part 4 of a format code affects strings
+	public static function toFormattedString($value = '', $format = '', $callBack = null)
+	{
+		// For now we do not treat strings although section 4 of a format code affects strings
 		if (!is_numeric($value)) return $value;
 
 		// For 'General' format code, we just pass the value although this is not entirely the way Excel does it,
 		// it seems to round numbers to a total of 10 digits.
-		if ($format === 'General') {
+		if (($format === PHPExcel_Style_NumberFormat::FORMAT_GENERAL) || ($format === PHPExcel_Style_NumberFormat::FORMAT_TEXT)) {
 			return $value;
 		}
 
-		// Get the parts, there can be up to four parts
-		$parts = explode(';', $format);
+		// Get the sections, there can be up to four sections
+		$sections = explode(';', $format);
 
-		// We should really fetch the relevant part depending on whether we have a positive number,
-		// negative number, zero, or text. But for now we just use first part
-		$format = $parts[0];
+		// Fetch the relevant section depending on whether number is positive, negative, or zero?
+		// Text not supported yet.
+		// Here is how the sections apply to various values in Excel:
+		//   1 section:   [POSITIVE/NEGATIVE/ZERO/TEXT]
+		//   2 sections:  [POSITIVE/ZERO/TEXT] [NEGATIVE]
+		//   3 sections:  [POSITIVE/TEXT] [NEGATIVE] [ZERO]
+		//   4 sections:  [POSITIVE] [NEGATIVE] [ZERO] [TEXT]
+		switch (count($sections)) {
+			case 1:
+				$format = $sections[0];
+				break;
 
-		if (preg_match("/^[hmsdy]/i", $format)) { // custom datetime format
+			case 2:
+				$format = ($value >= 0) ? $sections[0] : $sections[1];
+				$value = abs($value); // Use the absolute value
+				break;
+
+			case 3:
+				$format = ($value > 0) ?
+					$sections[0] : ( ($value < 0) ?
+						$sections[1] : $sections[2]);
+				$value = abs($value); // Use the absolute value
+				break;
+
+			case 4:
+				$format = ($value > 0) ?
+					$sections[0] : ( ($value < 0) ?
+						$sections[1] : $sections[2]);
+				$value = abs($value); // Use the absolute value
+				break;
+
+			default:
+				// something is wrong, just use first section
+				$format = $sections[0];
+				break;
+		}
+
+		// Save format with color information for later use below
+		$formatColor = $format;
+
+		// Strip color information
+		$color_regex = '/^\\[[a-zA-Z]+\\]/';
+		$format = preg_replace($color_regex, '', $format);
+
+		// Let's begin inspecting the format and converting the value to a formatted string
+		if (preg_match('/^(\[\$[A-Z]*-[0-9A-F]*\])*[hmsdy]/i', $format)) { // datetime format
 			// dvc: convert Excel formats to PHP date formats
-			// first remove escapes related to non-format characters
+
+			// strip off first part containing e.g. [$-F800] or [$USD-409]
+			// general syntax: [$<Currency string>-<language info>]
+			// language info is in hexadecimal
+			$format = preg_replace('/^(\[\$[A-Z]*-[0-9A-F]*\])/i', '', $format);
 
 			// OpenOffice.org uses upper-case number formats, e.g. 'YYYY', convert to lower-case
 			$format = strtolower($format);
 
-			$format = str_replace('\\', '', $format);
-
-			//	4-digit year
-			$format = str_replace('yyyy', 'Y', $format);
-			//	2-digit year
-			$format = str_replace('yy', 'y', $format);
-			//	first letter of month - no php equivalent
-			$format = str_replace('mmmmm', 'M', $format);
-			//	full month name
-			$format = str_replace('mmmm', 'F', $format);
-			//	short month name
-			$format = str_replace('mmm', 'M', $format);
-			//	mm is minutes if time or month w/leading zero
-			$format = str_replace(':mm', ':i', $format);
-			//	tmp place holder
-			$format = str_replace('mm', 'x', $format);
-			//	month no leading zero
-			$format = str_replace('m', 'n', $format);
-			//	month leading zero
-			$format = str_replace('x', 'm', $format);
-			//	12-hour suffix
-			$format = str_replace('am/pm', 'A', $format);
-			//	full day of week name
-			$format = str_replace('dddd', 'l', $format);
-			//	short day of week name
-			$format = str_replace('ddd', 'D', $format);
-			//	tmp place holder
-			$format = str_replace('dd', 'x', $format);
-			//	days no leading zero
-			$format = str_replace('d', 'j', $format);
-			//	days leading zero
-			$format = str_replace('x', 'd', $format);
-			//	seconds
-			$format = str_replace('ss', 's', $format);
-			//	fractional seconds - no php equivalent
-			$format = str_replace('.s', '', $format);
-
-			if (!strpos($format,'A')) { // 24-hour format
-				$format = str_replace('h', 'H', $format);
+			$format = strtr($format,self::$_dateFormatReplacements);
+			if (!strpos($format,'A')) {	// 24-hour time format
+				$format = strtr($format,self::$_dateFormatReplacements24);
+			} else {					// 12-hour time format
+				$format = strtr($format,self::$_dateFormatReplacements12);
 			}
 
-			return gmdate($format, PHPExcel_Shared_Date::ExcelToPHP($value));
+			$dateObj = PHPExcel_Shared_Date::ExcelToPHPObject($value);
+			$value = $dateObj->format($format);
 
 		} else if (preg_match('/%$/', $format)) { // % number format
 			if ($format === self::FORMAT_PERCENTAGE) {
-				return round( (100 * $value), 0) . '%';
-			}
-			if (preg_match('/\.[#0]+/i', $format, $m)) {
-				$s = substr($m[0], 0, 1) . (strlen($m[0]) - 1);
-				$format = str_replace($m[0], $s, $format);
-			}
-			if (preg_match('/^[#0]+/', $format, $m)) {
-				$format = str_replace($m[0], strlen($m[0]), $format);
-			}
-			$format = '%' . str_replace('%', 'f%%', $format);
+				$value = round( (100 * $value), 0) . '%';
+			} else {
+				if (preg_match('/\.[#0]+/i', $format, $m)) {
+					$s = substr($m[0], 0, 1) . (strlen($m[0]) - 1);
+					$format = str_replace($m[0], $s, $format);
+				}
+				if (preg_match('/^[#0]+/', $format, $m)) {
+					$format = str_replace($m[0], strlen($m[0]), $format);
+				}
+				$format = '%' . str_replace('%', 'f%%', $format);
 
-			return sprintf($format, 100 * $value);
+				$value = sprintf($format, 100 * $value);
+			}
 
 		} else {
-			if (preg_match ("/^([0-9.,-]+)$/", $value)) {
-	 			if ($format === self::FORMAT_CURRENCY_EUR_SIMPLE) {
-	 				return 'EUR ' . sprintf('%1.2f', $value);
+			if ($format === self::FORMAT_CURRENCY_EUR_SIMPLE) {
+				$value = 'EUR ' . sprintf('%1.2f', $value);
 
-				} else {
-					// In Excel formats, "_" is used to add spacing, which we can't do in HTML
-					$format = preg_replace('/_./', '', $format);
+			} else {
+				// In Excel formats, "_" is used to add spacing, which we can't do in HTML
+				$format = preg_replace('/_./', '', $format);
 
-					// Some non-number characters are escaped with \, which we don't need
-					$format = preg_replace("/\\\\/", '', $format);
+				// Some non-number characters are escaped with \, which we don't need
+				$format = preg_replace("/\\\\/", '', $format);
 
-					// Some non-number strings are quoted, so we'll get rid of the quotes
-					$format = preg_replace('/"/', '', $format);
+				// Some non-number strings are quoted, so we'll get rid of the quotes, likewise any positional * symbols
+				$format = str_replace(array('"','*'), '', $format);
 
-					// TEMPORARY - Convert # to 0
-					$format = preg_replace('/\\#/', '0', $format);
+				// Find out if we need thousands separator
+				// This is indicated by a comma enclosed by a digit placeholder:
+				//		#,#   or   0,0
+				$useThousands = preg_match('/(#,#|0,0)/', $format);
+				if ($useThousands) {
+					$format = preg_replace('/0,0/', '00', $format);
+					$format = preg_replace('/#,#/', '##', $format);
+				}
 
-					// Find out if we need thousands separator
-					$useThousands = preg_match('/,/', $format);
-					if ($useThousands) {
-						$format = preg_replace('/,/', '', $format);
-					}
+				// Scale thousands, millions,...
+				// This is indicated by a number of commas after a digit placeholder:
+				//		#,   or	0.0,,
+				$scale = 1; // same as no scale
+				$matches = array();
+				if (preg_match('/(#|0)(,+)/', $format, $matches)) {
+					$scale = pow(1000, strlen($matches[2]));
 
-					if (preg_match('/0?.*\?\/\?/', $format, $m)) {
-						//echo 'Format mask is fractional '.$format.' <br />';
+					// strip the commas
+					$format = preg_replace('/0,+/', '0', $format);
+					$format = preg_replace('/#,+/', '#', $format);
+				}
+
+				if (preg_match('/#?.*\?\/\?/', $format, $m)) {
+					//echo 'Format mask is fractional '.$format.' <br />';
+					if ($value != (int)$value) {
 						$sign = ($value < 0) ? '-' : '';
 
 						$integerPart = floor(abs($value));
@@ -613,46 +640,75 @@ class PHPExcel_Style_NumberFormat implements PHPExcel_IComparable
 						$decimalLength = strlen($decimalPart);
 						$decimalDivisor = pow(10,$decimalLength);
 
-						$GCD = PHPExcel_Calculation_Functions::GCD($decimalPart,$decimalDivisor);
+						$GCD = PHPExcel_Calculation_MathTrig::GCD($decimalPart,$decimalDivisor);
 
 						$adjustedDecimalPart = $decimalPart/$GCD;
 						$adjustedDecimalDivisor = $decimalDivisor/$GCD;
 
-						if (strpos($format,'0') !== false) {
+						if ((strpos($format,'0') !== false) || (strpos($format,'#') !== false) || (substr($format,0,3) == '? ?')) {
+							if ($integerPart == 0) { $integerPart = ''; }
 							$value = "$sign$integerPart $adjustedDecimalPart/$adjustedDecimalDivisor";
 						} else {
 							$adjustedDecimalPart += $integerPart * $adjustedDecimalDivisor;
 							$value = "$sign$adjustedDecimalPart/$adjustedDecimalDivisor";
 						}
-
-					} else {
-						// Handle the number itself
-						$number_regex = "/(\d+)(\.?)(\d*)/";
-						if (preg_match($number_regex, $format, $matches)) {
-							$left = $matches[1];
-							$dec = $matches[2];
-							$right = $matches[3];
-							if ($useThousands) {
-								$localeconv = localeconv();
-								if (($localeconv['thousands_sep'] == '') || ($localeconv['decimal_point'] == '')) {
-									$value = number_format($value, strlen($right), $localeconv['mon_decimal_point'], $localeconv['mon_thousands_sep']);
-								} else {
-									$value = number_format($value, strlen($right), $localeconv['decimal_point'], $localeconv['thousands_sep']);
-								}
-							} else {
-								$sprintf_pattern = "%1." . strlen($right) . "f";
-								$value = sprintf($sprintf_pattern, $value);
-							}
-							$value = preg_replace($number_regex, $value, $format);
-						}
 					}
 
-					return $value;
+				} else {
+					// Handle the number itself
 
+					// scale number
+					$value = $value / $scale;
+
+					// Strip #
+					$format = preg_replace('/\\#/', '', $format);
+
+					$n = "/\[[^\]]+\]/";
+					$m = preg_replace($n, '', $format);
+					$number_regex = "/(0+)(\.?)(0*)/";
+					if (preg_match($number_regex, $m, $matches)) {
+						$left = $matches[1];
+						$dec = $matches[2];
+						$right = $matches[3];
+
+						// minimun width of formatted number (including dot)
+						$minWidth = strlen($left) + strlen($dec) + strlen($right);
+
+						if ($useThousands) {
+							$value = number_format(
+										$value
+										, strlen($right)
+										, PHPExcel_Shared_String::getDecimalSeparator()
+										, PHPExcel_Shared_String::getThousandsSeparator()
+									);
+						} else {
+							$sprintf_pattern = "%0$minWidth." . strlen($right) . "f";
+							$value = sprintf($sprintf_pattern, $value);
+						}
+
+						$value = preg_replace($number_regex, $value, $format);
+					}
+				}
+				if (preg_match('/\[\$(.*)\]/u', $format, $m)) {
+					//	Currency or Accounting
+					$currencyFormat = $m[0];
+					$currencyCode = $m[1];
+					list($currencyCode) = explode('-',$currencyCode);
+					if ($currencyCode == '') {
+						$currencyCode = PHPExcel_Shared_String::getCurrencyCode();
+					}
+					$value = preg_replace('/\[\$([^\]]*)\]/u',$currencyCode,$value);
 				}
 			}
-
-			return $value;
 		}
+
+		// Additional formatting provided by callback function
+		if ($callBack !== null) {
+			list($writerInstance, $function) = $callBack;
+			$value = $writerInstance->$function($value, $formatColor);
+		}
+
+		return $value;
 	}
+
 }
