@@ -1,11 +1,10 @@
 <?php
-/* $Id: config.auth.lib.php,v 2.18 2005/12/08 20:47:24 nijel Exp $ */
-// vim: expandtab sw=4 ts=4 sts=4:
-
-// +--------------------------------------------------------------------------+
-// | Set of functions used to run config authentication (ie no                |
-// | authentication).                                                         |
-// +--------------------------------------------------------------------------+
+/* vim: set expandtab sw=4 ts=4 sts=4: */
+/**
+ * Set of functions used to run config authentication (ie no authentication).
+ *
+ * @package phpMyAdmin-Auth-Config
+ */
 
 
 /**
@@ -74,66 +73,65 @@ function PMA_auth_fails()
         if (isset($php_errormsg)) {
             $conn_error = $php_errormsg;
         } else {
-            $conn_error = $GLOBALS['strConnectionError'];
+            $conn_error = __('Cannot connect: invalid settings.');
         }
     }
 
     // Defines the charset to be used
     header('Content-Type: text/html; charset=' . $GLOBALS['charset']);
     /* HTML header */
-    $page_title = $GLOBALS['strAccessDenied'];
-    require('./libraries/header_meta_style.inc.php');
+    $page_title = __('Access denied');
+    require './libraries/header_meta_style.inc.php';
     ?>
 </head>
 
 <body>
 <br /><br />
 <center>
-    <h1><?php echo sprintf($GLOBALS['strWelcome'], ' phpMyAdmin ' . PMA_VERSION); ?></h1>
+    <h1><?php echo sprintf(__('Welcome to %s'), ' phpMyAdmin '); ?></h1>
 </center>
 <br />
 <table border="0" cellpadding="0" cellspacing="3" align="center" width="80%">
     <tr>
         <td>
+
     <?php
-    echo "\n";
     $GLOBALS['is_header_sent'] = TRUE;
 
-    //TODO: I have included this div from libraries/header.inc.php to work around
-    //      an undefined variable in tooltip.js, when the server
-    //      is not responding. Work has to be done to merge all code that
-    //      starts the page (DOCTYPE and this div) to one place
-    ?>
-    <div id="TooltipContainer" onmouseover="holdTooltip();" onmouseout="swapTooltip('default');"></div>
-    <?php
-
-    // if we display the "Server not responding" error, do not confuse users
-    // by telling them they have a settings problem
-    // (note: it's true that they could have a badly typed host name, but
-    //  anyway the current $strAccessDeniedExplanation tells that the server
-    //  rejected the connection, which is not really what happened)
-    // 2002 is the error given by mysqli
-    // 2003 is the error given by mysql
-
     if (isset($GLOBALS['allowDeny_forbidden']) && $GLOBALS['allowDeny_forbidden']) {
-        echo '<p>' . $GLOBALS['strAccessDenied'] . '</p>' . "\n";
+        trigger_error(__('Access denied'), E_USER_NOTICE);
     } else {
-        if (!isset($GLOBALS['errno']) || (isset($GLOBALS['errno']) && $GLOBALS['errno'] != 2002) && $GLOBALS['errno'] != 2003) {
-            // Check whether user has configured something
-            if ($_SESSION['PMA_Config']->source_mtime == 0) {
-                echo '<p>' . sprintf($GLOBALS['strAccessDeniedCreateConfig'], '<a href="scripts/setup.php">', '</a>') . '</p>' . "\n";
-            } else {
-                echo '<p>' . $GLOBALS['strAccessDeniedExplanation'] . '</p>' . "\n";
-            }
+        // Check whether user has configured something
+        if ($GLOBALS['PMA_Config']->source_mtime == 0) {
+            echo '<p>' . sprintf(__('You probably did not create a configuration file. You might want to use the %1$ssetup script%2$s to create one.'), '<a href="setup/">', '</a>') . '</p>' . "\n";
+        } elseif (!isset($GLOBALS['errno']) || (isset($GLOBALS['errno']) && $GLOBALS['errno'] != 2002) && $GLOBALS['errno'] != 2003) {
+        // if we display the "Server not responding" error, do not confuse users
+        // by telling them they have a settings problem
+        // (note: it's true that they could have a badly typed host name, but
+        //  anyway the current message tells that the server
+        //  rejected the connection, which is not really what happened)
+        // 2002 is the error given by mysqli
+        // 2003 is the error given by mysql
+            trigger_error(__('phpMyAdmin tried to connect to the MySQL server, and the server rejected the connection. You should check the host, username and password in your configuration and make sure that they correspond to the information given by the administrator of the MySQL server.'), E_USER_WARNING);
         }
-        PMA_mysqlDie($conn_error, '');
+        PMA_mysqlDie($conn_error, '', true, '', false);
     }
+    $GLOBALS['error_handler']->dispUserErrors();
 ?>
         </td>
     </tr>
-</table>
 <?php
-    require_once('./libraries/footer.inc.php');
+    if (count($GLOBALS['cfg']['Servers']) > 1) {
+        // offer a chance to login to other servers if the current one failed
+        require_once './libraries/select_server.lib.php';
+        echo '<tr>' . "\n";
+        echo ' <td>' . "\n";
+        PMA_select_server(TRUE, TRUE);
+        echo ' </td>' . "\n";
+        echo '</tr>' . "\n";
+    }
+    echo '</table>' . "\n";
+    require './libraries/footer.inc.php';
     return TRUE;
 } // end of the 'PMA_auth_fails()' function
 
