@@ -4,7 +4,6 @@
  * Interface to the classic MySQL extension
  *
  * @package phpMyAdmin-DBI-MySQL
- * @version $Id$
  */
 if (! defined('PHPMYADMIN')) {
     exit;
@@ -52,7 +51,7 @@ function PMA_DBI_real_connect($server, $user, $password, $client_flags, $persist
 function PMA_DBI_connect($user, $password, $is_controluser = false, $server = null, $auxiliary_connection = false)
 {
     global $cfg, $php_errormsg;
-  
+
     if ($server) {
         $server_port = (empty($server['port']))
             ? ''
@@ -64,12 +63,12 @@ function PMA_DBI_connect($user, $password, $is_controluser = false, $server = nu
             ? false
             : true;
     } else {
-	  $server_port   = (empty($cfg['Server']['port']))
-                   ? ''
-                   : ':' . (int)$cfg['Server']['port'];
-	  $server_socket = (empty($cfg['Server']['socket']))
-                   ? ''
-                   : ':' . $cfg['Server']['socket'];
+        $server_port   = (empty($cfg['Server']['port']))
+            ? ''
+            : ':' . (int)$cfg['Server']['port'];
+        $server_socket = (empty($cfg['Server']['socket']))
+            ? ''
+            : ':' . $cfg['Server']['socket'];
     }
 
     if (strtolower($cfg['Server']['connect_type']) == 'tcp') {
@@ -92,24 +91,24 @@ function PMA_DBI_connect($user, $password, $is_controluser = false, $server = nu
     if (defined('MYSQL_CLIENT_SSL') && $cfg['Server']['ssl']) {
         $client_flags |= MYSQL_CLIENT_SSL;
     }
-    
+
     if (!$server) {
         $link = PMA_DBI_real_connect($cfg['Server']['host'] . $server_port . $server_socket, $user, $password, empty($client_flags) ? NULL : $client_flags);
 
       // Retry with empty password if we're allowed to
         if (empty($link) && $cfg['Server']['nopassword'] && !$is_controluser) {
-	        $link = PMA_DBI_real_connect($cfg['Server']['host'] . $server_port . $server_socket, $user, '', empty($client_flags) ? NULL : $client_flags);
+            $link = PMA_DBI_real_connect($cfg['Server']['host'] . $server_port . $server_socket, $user, '', empty($client_flags) ? NULL : $client_flags);
         }
     } else {
         if (!isset($server['host'])) {
-	        $link = PMA_DBI_real_connect($server_socket, $user, $password, NULL, $server_persistant); 
+            $link = PMA_DBI_real_connect($server_socket, $user, $password, NULL, $server_persistant);
         } else {
             $link = PMA_DBI_real_connect($server['host'] . $server_port . $server_socket, $user, $password, NULL, $server_persistant);
         }
     }
     if (empty($link)) {
         if ($is_controluser) {
-            trigger_error($GLOBALS['strControluserFailed'], E_USER_WARNING);
+            trigger_error(__('Connection for controluser as defined in your configuration failed.'), E_USER_WARNING);
             return false;
         }
         // we could be calling PMA_DBI_connect() to connect to another
@@ -155,7 +154,7 @@ function PMA_DBI_select_db($dbname, $link = null)
  * @param integer $options
  * @return mixed
  */
-function PMA_DBI_try_query($query, $link = null, $options = 0)
+function PMA_DBI_try_query($query, $link = null, $options = 0, $cache_affected_rows = true)
 {
     if (empty($link)) {
         if (isset($GLOBALS['userlink'])) {
@@ -176,6 +175,10 @@ function PMA_DBI_try_query($query, $link = null, $options = 0)
         $r = mysql_query($query, $link);
     }
 
+    if ($cache_affected_rows) { 
+       $GLOBALS['cached_affected_rows'] = PMA_DBI_affected_rows($link, $get_from_cache = false); 
+    }
+
     if ($GLOBALS['cfg']['DBG']['sql']) {
         $time = microtime(true) - $time;
 
@@ -206,7 +209,7 @@ function PMA_DBI_try_query($query, $link = null, $options = 0)
         $_SESSION['debug']['queries'][$hash]['trace'][] = $trace;
     }
     if ($r != FALSE && PMA_Tracker::isActive() == TRUE ) {
-        PMA_Tracker::handleQuery($query); 
+        PMA_Tracker::handleQuery($query);
     }
 
     return $r;
@@ -308,9 +311,6 @@ function PMA_DBI_get_client_info()
  * @uses    PMA_DBI_convert_message()
  * @uses    $GLOBALS['errno']
  * @uses    $GLOBALS['userlink']
- * @uses    $GLOBALS['strServerNotResponding']
- * @uses    $GLOBALS['strSocketProblem']
- * @uses    $GLOBALS['strDetails']
  * @uses    mysql_errno()
  * @uses    mysql_error()
  * @uses    defined()
@@ -321,6 +321,12 @@ function PMA_DBI_get_client_info()
 function PMA_DBI_getError($link = null)
 {
     $GLOBALS['errno'] = 0;
+
+    /* Treat false same as null because of controllink */
+    if ($link === false) {
+        $link = null;
+    }
+
     if (null === $link && isset($GLOBALS['userlink'])) {
         $link =& $GLOBALS['userlink'];
 
@@ -348,18 +354,20 @@ function PMA_DBI_getError($link = null)
         $error_message = PMA_DBI_convert_message($error_message);
     }
 
+    $error_message = htmlspecialchars($error_message);
+
     // Some errors messages cannot be obtained by mysql_error()
     if ($error_number == 2002) {
-        $error = '#' . ((string) $error_number) . ' - ' . $GLOBALS['strServerNotResponding'] . ' ' . $GLOBALS['strSocketProblem'];
+        $error = '#' . ((string) $error_number) . ' - ' . __('The server is not responding') . ' ' . __('(or the local MySQL server\'s socket is not correctly configured)');
     } elseif ($error_number == 2003) {
-        $error = '#' . ((string) $error_number) . ' - ' . $GLOBALS['strServerNotResponding'];
+        $error = '#' . ((string) $error_number) . ' - ' . __('The server is not responding');
     } elseif ($error_number == 1005) {
         /* InnoDB contraints, see
          * http://dev.mysql.com/doc/refman/5.0/en/innodb-foreign-key-constraints.html
          */
         $error = '#' . ((string) $error_number) . ' - ' . $error_message .
             ' (<a href="server_engines.php' . PMA_generate_common_url(array('engine' => 'InnoDB', 'page' => 'Status')).
-            '">' . $GLOBALS['strDetails'] . '</a>)';
+            '">' . __('Details...') . '</a>)';
     } else {
         $error = '#' . ((string) $error_number) . ' - ' . $error_message;
     }
@@ -384,17 +392,24 @@ function PMA_DBI_insert_id($link = null)
             return false;
         }
     }
-    //$insert_id = mysql_insert_id($link);
-    // if the primary key is BIGINT we get an incorrect result
+    // If the primary key is BIGINT we get an incorrect result
     // (sometimes negative, sometimes positive)
     // and in the present function we don't know if the PK is BIGINT
     // so better play safe and use LAST_INSERT_ID()
     //
-    // by the way, no problem with mysqli_insert_id()
     return PMA_DBI_fetch_value('SELECT LAST_INSERT_ID();', 0, 0, $link);
 }
 
-function PMA_DBI_affected_rows($link = null)
+/**
+ * returns the number of rows affected by last query
+ *
+ * @uses    $GLOBALS['userlink']
+ * @uses    mysql_affected_rows()
+ * @param   object mysql   $link   the mysql object
+ * @param   boolean        $get_from_cache 
+ * @return  string integer
+ */
+function PMA_DBI_affected_rows($link = null, $get_from_cache = true)
 {
     if (empty($link)) {
         if (isset($GLOBALS['userlink'])) {
@@ -403,7 +418,12 @@ function PMA_DBI_affected_rows($link = null)
             return false;
         }
     }
-    return mysql_affected_rows($link);
+
+    if ($get_from_cache) {
+        return $GLOBALS['cached_affected_rows'];
+    } else {
+        return mysql_affected_rows($link);
+    }
 }
 
 /**
