@@ -3,27 +3,36 @@
 /**
  * This is in a separate script because it's called from a number of scripts
  *
- * @version $Id$
  * @package phpMyAdmin
  */
 
 /**
  * Sanitizes $message, taking into account our special codes
- * for formatting
+ * for formatting.
+ *
+ * If you want to include result in element attribute, you should escape it.
+ *
+ * Examples:
+ *
+ * <p><?php echo PMA_sanitize($foo); ?></p>
+ *
+ * <a title="<?php echo PMA_sanitize($foo, true); ?>">bar</a>
  *
  * @uses    preg_replace()
  * @uses    strtr()
  * @param   string   the message
+ * @param   boolean  whether to escape html in result
  *
  * @return  string   the sanitized message
  *
  * @access  public
  */
-function PMA_sanitize($message)
+function PMA_sanitize($message, $escape = false, $safe = false)
 {
+    if (!$safe) {
+        $message = strtr($message, array('<' => '&lt;', '>' => '&gt;'));
+    }
     $replace_pairs = array(
-        '<'         => '&lt;',
-        '>'         => '&gt;',
         '[i]'       => '<em>',      // deprecated by em
         '[/i]'      => '</em>',     // deprecated by em
         '[em]'      => '<em>',
@@ -64,7 +73,15 @@ function PMA_sanitize($message)
             }
         }
 
-        $message = preg_replace($pattern, '<a href="\1" target="\2">', $message);
+        if (substr($found[1], 0, 4) == 'http') {
+            $message = preg_replace($pattern, '<a href="' . PMA_linkURL($found[1]) . '" target="\2">', $message);
+        } else {
+            $message = preg_replace($pattern, '<a href="\1" target="\2">', $message);
+        }
+    }
+
+    if ($escape) {
+        $message = htmlspecialchars($message);
     }
 
     return $message;
