@@ -1,9 +1,8 @@
 <?php
 /* vim: set expandtab sw=4 ts=4 sts=4: */
 /**
- * Code for displaying server selection written by nijel
+ * Code for displaying server selection
  *
- * @version $Id: select_server.lib.php 11986 2008-11-24 11:05:40Z nijel $
  * @package phpMyAdmin
  */
 
@@ -11,9 +10,7 @@
  * display server selection in list or selectbox form, or option tags only
  *
  * @uses    $GLOBALS['cfg']['DisplayServersList']
- * @uses    $GLOBALS['strServer']
  * @uses    $GLOBALS['cfg']['Servers']
- * @uses    $GLOBALS['strGo']
  * @uses    implode()
  * @uses    htmlspecialchars()
  * @uses    PMA_generate_common_hidden_inputs()
@@ -38,13 +35,13 @@ function PMA_select_server($not_only_options, $ommit_fieldset)
         if (! $ommit_fieldset) {
             echo '<fieldset>';
         }
-        echo '<label for="select_server">' . $GLOBALS['strServer'] . ':</label> ';
+        echo '<label for="select_server">' . __('Current Server') . ':</label> ';
 
         echo '<select name="server" id="select_server"'
             . ' onchange="if (this.value != \'\') this.form.submit();">';
-        echo '<option value="">(' . $GLOBALS['strServers'] . ') ...</option>' . "\n";
+        echo '<option value="">(' . __('Servers') . ') ...</option>' . "\n";
     } elseif ($list) {
-        echo $GLOBALS['strServer'] . ':<br />';
+        echo __('Current Server') . ':<br />';
         echo '<ul id="list_server">';
     }
 
@@ -58,7 +55,6 @@ function PMA_select_server($not_only_options, $ommit_fieldset)
         } else {
             $selected = 0;
         }
-
         if (!empty($server['verbose'])) {
             $label = $server['verbose'];
         } else {
@@ -81,7 +77,7 @@ function PMA_select_server($not_only_options, $ommit_fieldset)
 
         if ($list) {
             echo '<li>';
-            if ($selected && !$ommit_fieldset) {
+            if ($selected) {
                 echo '<strong>' . htmlspecialchars($label) . '</strong>';
             } else {
 
@@ -101,7 +97,7 @@ function PMA_select_server($not_only_options, $ommit_fieldset)
         echo '</select>';
         // Show submit button if we have just one server (this happens with no default)
         echo '<noscript>';
-        echo '<input type="submit" value="' . $GLOBALS['strGo'] . '" />';
+        echo '<input type="submit" value="' . __('Go') . '" />';
         echo '</noscript>';
         if (! $ommit_fieldset) {
             echo '</fieldset>';
