@@ -5,7 +5,6 @@
  *
  * usally called as form action from tbl_change.php to insert or update table rows
  *
- * @version $Id: tbl_replace.php 13118 2009-11-21 13:22:08Z lem9 $
  *
  * @todo 'edit_next' tends to not work as expected if used ... at least there is no order by
  *       it needs the original query and the row number and than replace the LIMIT clause
@@ -54,6 +53,7 @@ if (! defined('PMA_NO_VARIABLES_IMPORT')) {
  * Gets some core libraries
  */
 require_once './libraries/common.inc.php';
+$blob_streaming_active = $GLOBALS['PMA_Config']->get('BLOBSTREAMING_PLUGINS_EXIST');
 
 // Check parameters
 PMA_checkParameters(array('db', 'table', 'goto'));
@@ -65,6 +65,9 @@ PMA_DBI_select_db($GLOBALS['db']);
  */
 $goto_include = false;
 
+// Needed for generation of Inline Edit anchors
+$GLOBALS['js_include'][] = 'sql.js';
+
 if (isset($_REQUEST['insert_rows']) && is_numeric($_REQUEST['insert_rows']) && $_REQUEST['insert_rows'] != $cfg['InsertRows']) {
     $cfg['InsertRows'] = $_REQUEST['insert_rows'];
     $GLOBALS['js_include'][] = 'tbl_change.js';
@@ -79,15 +82,15 @@ if (isset($_REQUEST['after_insert'])
     //$GLOBALS['goto'] = 'tbl_change.php';
     $goto_include = 'tbl_change.php';
 
-    if (isset($_REQUEST['primary_key'])) {
+    if (isset($_REQUEST['where_clause'])) {
         if ($_REQUEST['after_insert'] == 'same_insert') {
-            foreach ($_REQUEST['primary_key'] as $pk) {
-                $url_params['primary_key'][] = $pk;
+            foreach ($_REQUEST['where_clause'] as $one_where_clause) {
+                $url_params['where_clause'][] = $one_where_clause;
             }
         } elseif ($_REQUEST['after_insert'] == 'edit_next') {
-            foreach ($_REQUEST['primary_key'] as $pk) {
+            foreach ($_REQUEST['where_clause'] as $one_where_clause) {
                 $local_query    = 'SELECT * FROM ' . PMA_backquote($GLOBALS['db']) . '.' . PMA_backquote($GLOBALS['table'])
-                                . ' WHERE ' . str_replace('` =', '` >', $pk)
+                                . ' WHERE ' . str_replace('` =', '` >', $one_where_clause)
                                 . ' LIMIT 1;';
                 $res            = PMA_DBI_query($local_query);
                 $row            = PMA_DBI_fetch_row($res);
@@ -133,11 +136,12 @@ if (isset($_REQUEST['err_url'])) {
 /**
  * Prepares the update/insert of a row
  */
-if (isset($_REQUEST['primary_key'])) {
-    // we were editing something => use primary key
-    $loop_array = (is_array($_REQUEST['primary_key']) ? $_REQUEST['primary_key'] : array($_REQUEST['primary_key']));
+if (isset($_REQUEST['where_clause'])) {
+    // we were editing something => use the WHERE clause
+    $loop_array = (is_array($_REQUEST['where_clause']) ? $_REQUEST['where_clause'] : array($_REQUEST['where_clause']));
     $using_key  = true;
-    $is_insert  = ($_REQUEST['submit_type'] == $GLOBALS['strInsertAsNewRow']);
+    $is_insert  = ($_REQUEST['submit_type'] == 'insert') || ($_REQUEST['submit_type'] == 'showinsert') || ($_REQUEST['submit_type'] == 'insertignore');
+    $is_insertignore  = ($_REQUEST['submit_type'] == 'insertignore');
 } else {
     // new row => use indexes
     $loop_array = array();
@@ -146,6 +150,7 @@ if (isset($_REQUEST['primary_key'])) {
     }
     $using_key  = false;
     $is_insert  = true;
+    $is_insertignore = false;
 }
 
 $query = array();
@@ -165,9 +170,9 @@ $func_no_param = array(
     'CURRENT_USER',
 );
 
-foreach ($loop_array as $rowcount => $primary_key) {
+foreach ($loop_array as $rownumber => $where_clause) {
     // skip fields to be ignored
-    if (! $using_key && isset($_REQUEST['insert_ignore_' . $primary_key])) {
+    if (! $using_key && isset($_REQUEST['insert_ignore_' . $where_clause])) {
         continue;
     }
 
@@ -176,49 +181,42 @@ foreach ($loop_array as $rowcount => $primary_key) {
 
     // Map multi-edit keys to single-level arrays, dependent on how we got the fields
     $me_fields =
-        isset($_REQUEST['fields']['multi_edit'][$rowcount])
-        ? $_REQUEST['fields']['multi_edit'][$rowcount]
+        isset($_REQUEST['fields']['multi_edit'][$rownumber])
+        ? $_REQUEST['fields']['multi_edit'][$rownumber]
         : array();
     $me_fields_name =
-        isset($_REQUEST['fields_name']['multi_edit'][$rowcount])
-        ? $_REQUEST['fields_name']['multi_edit'][$rowcount]
+        isset($_REQUEST['fields_name']['multi_edit'][$rownumber])
+        ? $_REQUEST['fields_name']['multi_edit'][$rownumber]
         : null;
     $me_fields_prev =
-        isset($_REQUEST['fields_prev']['multi_edit'][$rowcount])
-        ? $_REQUEST['fields_prev']['multi_edit'][$rowcount]
+        isset($_REQUEST['fields_prev']['multi_edit'][$rownumber])
+        ? $_REQUEST['fields_prev']['multi_edit'][$rownumber]
         : null;
     $me_funcs =
-        isset($_REQUEST['funcs']['multi_edit'][$rowcount])
-        ? $_REQUEST['funcs']['multi_edit'][$rowcount]
+        isset($_REQUEST['funcs']['multi_edit'][$rownumber])
+        ? $_REQUEST['funcs']['multi_edit'][$rownumber]
         : null;
     $me_fields_type =
-        isset($_REQUEST['fields_type']['multi_edit'][$rowcount])
-        ? $_REQUEST['fields_type']['multi_edit'][$rowcount]
+        isset($_REQUEST['fields_type']['multi_edit'][$rownumber])
+        ? $_REQUEST['fields_type']['multi_edit'][$rownumber]
         : null;
     $me_fields_null =
-        isset($_REQUEST['fields_null']['multi_edit'][$rowcount])
-        ? $_REQUEST['fields_null']['multi_edit'][$rowcount]
+        isset($_REQUEST['fields_null']['multi_edit'][$rownumber])
+        ? $_REQUEST['fields_null']['multi_edit'][$rownumber]
         : null;
     $me_fields_null_prev =
-        isset($_REQUEST['fields_null_prev']['multi_edit'][$rowcount])
-        ? $_REQUEST['fields_null_prev']['multi_edit'][$rowcount]
+        isset($_REQUEST['fields_null_prev']['multi_edit'][$rownumber])
+        ? $_REQUEST['fields_null_prev']['multi_edit'][$rownumber]
         : null;
     $me_auto_increment =
-        isset($_REQUEST['auto_increment']['multi_edit'][$rowcount])
-        ? $_REQUEST['auto_increment']['multi_edit'][$rowcount]
+        isset($_REQUEST['auto_increment']['multi_edit'][$rownumber])
+        ? $_REQUEST['auto_increment']['multi_edit'][$rownumber]
         : null;
 
-	$primary_field = PMA_BS_GetPrimaryField($GLOBALS['db'], $GLOBALS['table']);
-
     // Fetch the current values of a row to use in case we have a protected field
     // @todo possibly move to ./libraries/tbl_replace_fields.inc.php
-    if ($is_insert && $using_key && isset($me_fields_type) &&
-        is_array($me_fields_type) && isset($primary_key)) {
-        $prot_result = PMA_DBI_query('SELECT * FROM ' .
-                PMA_backquote($table) . ' WHERE ' . $primary_key . ';');
-        $prot_row = PMA_DBI_fetch_assoc($prot_result);
-        PMA_DBI_free_result($prot_result);
-        unset($prot_result);
+    if ($is_insert && $using_key && isset($me_fields_type) && is_array($me_fields_type) && isset($where_clause)) {
+        $prot_row = PMA_DBI_fetch_single_row('SELECT * FROM ' . PMA_backquote($table) . ' WHERE ' . $where_clause . ';');
     }
     foreach ($me_fields as $key => $val) {
 
@@ -226,39 +224,39 @@ foreach ($loop_array as $rowcount => $primary_key) {
 
         require './libraries/tbl_replace_fields.inc.php';
 
-        // rajk - for blobstreaming
-	if (NULL != $primary_field || strlen($primary_field) > 0)
-	{
-		$remove_blob_repo = isset($_REQUEST['remove_blob_repo_' . $key]) ? $_REQUEST['remove_blob_repo_' . $key] : NULL;
-		$upload_blob_repo = isset($_REQUEST['upload_blob_repo_' . $key]) ? $_REQUEST['upload_blob_repo_' . $key] : NULL;
+        // for blobstreaming
+        if ($blob_streaming_active) {
+            $remove_blob_repo = isset($_REQUEST['remove_blob_repo_' . $key]) ? $_REQUEST['remove_blob_repo_' . $key] : NULL;
+            $upload_blob_repo = isset($_REQUEST['upload_blob_repo_' . $key]) ? $_REQUEST['upload_blob_repo_' . $key] : NULL;
 
-		// checks if an existing blob repository reference should be removed
-		if (isset($remove_blob_repo) && !isset($upload_blob_repo))
-		{
-			$remove_blob_reference = $_REQUEST['remove_blob_ref_' . $key];
+            // checks if an existing blob repository reference should be removed
+            if (isset($remove_blob_repo) && ! isset($upload_blob_repo)) {
+                $remove_blob_reference = $_REQUEST['remove_blob_ref_' . $key];
+                if (isset($remove_blob_reference)) {
+                    $val = "NULL";
+                }
+            }
 
-			if (isset($remove_blob_reference))
-				$val = "''";
-		}
+            // checks if this field requires a bs reference attached to it
+            if (isset($upload_blob_repo)) {
+                // get the most recent BLOB reference
+                $bs_reference = PMA_File::getRecentBLOBReference();
 
-		// checks if this field requires a bs reference attached to it
-		$requires_bs_reference = isset($upload_blob_repo);
-
-		if ($requires_bs_reference)
-		{
-			// get the most recent BLOB reference
-			$bs_reference = PMA_File::getRecentBLOBReference();
-
-			// if the most recent BLOB reference exists, set it as a field value
-			if (!is_null($bs_reference))
-				$val = "'" . PMA_sqlAddslashes($bs_reference) . "'";
-		}
-	}
+                // if the most recent BLOB reference exists, set it as a field value
+                if (!is_null($bs_reference)) {
+                    $val = "'" . PMA_sqlAddslashes($bs_reference) . "'";
+                }
+            }
+        }
 
         if (empty($me_funcs[$key])) {
             $cur_value = $val;
         } elseif ('UNIX_TIMESTAMP' === $me_funcs[$key] && $val != "''") {
             $cur_value = $me_funcs[$key] . '(' . $val . ')';
+        } elseif ('UUID' === $me_funcs[$key]) {
+            /* This way user will know what UUID new row has */
+            $uuid = PMA_DBI_fetch_value('SELECT UUID()');
+            $cur_value = "'" . $uuid . "'";
         } elseif (in_array($me_funcs[$key], $func_no_param)) {
             $cur_value = $me_funcs[$key] . '()';
         } else {
@@ -304,36 +302,41 @@ foreach ($loop_array as $rowcount => $primary_key) {
         } else {
             // build update query
             $query[] = 'UPDATE ' . PMA_backquote($GLOBALS['db']) . '.' . PMA_backquote($GLOBALS['table'])
-                . ' SET ' . implode(', ', $query_values) . ' WHERE ' . $primary_key . ($_REQUEST['clause_is_unique'] ? '' : ' LIMIT 1');
+                . ' SET ' . implode(', ', $query_values) . ' WHERE ' . $where_clause . ($_REQUEST['clause_is_unique'] ? '' : ' LIMIT 1');
 
         }
     }
-} // end foreach ($loop_array as $primary_key)
+} // end foreach ($loop_array as $where_clause)
 unset($me_fields_name, $me_fields_prev, $me_funcs, $me_fields_type, $me_fields_null, $me_fields_null_prev,
-    $me_auto_increment, $cur_value, $key, $val, $loop_array, $primary_key, $using_key,
+    $me_auto_increment, $cur_value, $key, $val, $loop_array, $where_clause, $using_key,
     $func_no_param);
 
 
 // Builds the sql query
 if ($is_insert && count($value_sets) > 0) {
-    $query[] = 'INSERT INTO ' . PMA_backquote($GLOBALS['db']) . '.' . PMA_backquote($GLOBALS['table'])
+    if ($is_insertignore) {
+        $insert_command = 'INSERT IGNORE ';
+    } else {
+        $insert_command = 'INSERT ';
+    }
+    $query[] = $insert_command . 'INTO ' . PMA_backquote($GLOBALS['db']) . '.' . PMA_backquote($GLOBALS['table'])
         . ' (' . implode(', ', $query_fields) . ') VALUES (' . implode('), (', $value_sets) . ')';
+    unset($insert_command);
 
-    unset($query_fields, $value_sets);
-
-    $message = PMA_Message::success('strRowsInserted');
-} elseif (! empty($query)) {
-    $message = PMA_Message::success('strRowsAffected');
-} else {
+    unset($query_fields);
+} elseif (empty($query)) {
     // No change -> move back to the calling script
-    $message = PMA_Message::success('strNoModification');
-    $GLOBALS['js_include'][] = 'functions.js';
+    //
+    // Note: logic passes here for inline edit
+    $message = PMA_Message::success(__('No change'));
     $active_page = $goto_include;
-    require_once './libraries/header.inc.php';
+    if(! $GLOBALS['is_ajax_request'] == true) {
+        require_once './libraries/header.inc.php';
+    }
     require './' . PMA_securePath($goto_include);
     exit;
 }
-unset($me_fields, $is_insert);
+unset($me_fields, $is_insertignore);
 
 /**
  * Executes the sql query and get the result, then move back to the calling
@@ -344,7 +347,7 @@ if (! empty($GLOBALS['sql_query'])) {
     $return_to_sql_query = $GLOBALS['sql_query'];
 }
 $GLOBALS['sql_query'] = implode('; ', $query) . ';';
-// to ensure that the query is displayed in case of 
+// to ensure that the query is displayed in case of
 // "insert as new row" and then "insert another new row"
 $GLOBALS['display_query'] = $GLOBALS['sql_query'];
 
@@ -354,6 +357,10 @@ $warning_messages = array();
 $error_messages = array();
 
 foreach ($query as $single_query) {
+    if ($_REQUEST['submit_type'] == 'showinsert') {
+        $last_messages[] = PMA_Message::notice(__('Showing SQL query'));
+        continue;
+    }
     if ($GLOBALS['cfg']['IgnoreMultiSubmitErrors']) {
         $result = PMA_DBI_try_query($single_query);
     } else {
@@ -363,9 +370,11 @@ foreach ($query as $single_query) {
     if (! $result) {
         $error_messages[] = PMA_DBI_getError();
     } else {
-        if (@PMA_DBI_affected_rows()) {
-            $total_affected_rows += @PMA_DBI_affected_rows();
+        // The next line contains a real assignment, it's not a typo
+        if ($tmp = @PMA_DBI_affected_rows()) {
+            $total_affected_rows += $tmp;
         }
+        unset($tmp);
 
         $insert_id = PMA_DBI_insert_id();
         if ($insert_id != 0) {
@@ -375,7 +384,7 @@ foreach ($query as $single_query) {
             if ($total_affected_rows > 0) {
                 $insert_id = $insert_id + $total_affected_rows - 1;
             }
-            $last_message = PMA_Message::notice('strInsertedRowId');
+            $last_message = PMA_Message::notice(__('Inserted row id: %1$d'));
             $last_message->addParam($insert_id);
             $last_messages[] = $last_message;
         }
@@ -391,16 +400,21 @@ foreach ($query as $single_query) {
 }
 unset($single_query, $query);
 
-$message->addParam($total_affected_rows);
+if ($is_insert && count($value_sets) > 0) {
+    $message = PMA_Message::inserted_rows($total_affected_rows);
+} else {
+    $message = PMA_Message::affected_rows($total_affected_rows);
+}
+
 $message->addMessages($last_messages, '<br />');
 
 if (! empty($warning_messages)) {
     /**
-     * @todo use a <div class="warning"> in PMA_showMessage() for this part of
+     * @todo use a <div class="error"> in PMA_showMessage() for this part of
      * the message
      */
     $message->addMessages($warning_messages, '<br />');
-    $message->isWarning(true);
+    $message->isError(true);
 }
 if (! empty($error_messages)) {
     $message->addMessages($error_messages);
@@ -408,6 +422,12 @@ if (! empty($error_messages)) {
 }
 unset($error_messages, $warning_messages, $total_affected_rows, $last_messages, $last_message);
 
+if($GLOBALS['is_ajax_request'] == true) {
+
+    $extra_data['sql_query'] = PMA_showMessage(NULL, $GLOBALS['display_query']);
+    PMA_ajaxResponse($message, $message->isSuccess(), $extra_data);
+}
+
 if (isset($return_to_sql_query)) {
     $disp_query = $GLOBALS['sql_query'];
     $disp_message = $message;
@@ -416,19 +436,18 @@ if (isset($return_to_sql_query)) {
 }
 
 $GLOBALS['js_include'][] = 'tbl_change.js';
-$GLOBALS['js_include'][] = 'functions.js';
 // in case we call sql.php which needs those:
-$GLOBALS['js_include'][] = 'mootools.js';
+$GLOBALS['js_include'][] = 'jquery/jquery-ui-1.8.custom.js';
 
 $active_page = $goto_include;
 
 /**
  * If user asked for "and then Insert another new row" we have to remove
- * primary key information so that tbl_change.php does not go back
+ * WHERE clause information so that tbl_change.php does not go back
  * to the current record
  */
 if (isset($_REQUEST['after_insert']) && 'new_insert' == $_REQUEST['after_insert']) {
-        unset($_REQUEST['primary_key']);
+        unset($_REQUEST['where_clause']);
 }
 
 /**
